@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: cbanking.c,v $
  -------------------
- cvs         : $Id: cbanking.c,v 1.1 2005/08/05 18:13:02 aquamaniac Exp $
+ cvs         : $Id: cbanking.c,v 1.2 2006/01/24 14:34:50 aquamaniac Exp $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -177,7 +177,7 @@ int CBanking__ConvertFromUtf8(AB_BANKING *ab,
     }
   }
 
-  GWEN_Buffer_AppendString(tbuf, text);
+  GWEN_Buffer_AppendBytes(tbuf, text, len);
   return 0;
 }
 
