@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: settings.h,v $
                              -------------------
-    cvs         : $Id: settings.h,v 1.2 2005/08/08 15:24:03 aquamaniac Exp $
+    cvs         : $Id: settings.h,v 1.3 2006/01/13 13:59:56 cstim Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -15,24 +15,13 @@
 
 
 
-#include "settings.ui.h"
-#include "kbaccountlist.h"
-#include "kbplugindescrlist.h"
-
-#include "kbanking.h"
+#include <kbanking/kbanking.h>
+#include <qbanking/qbcfgtabsettings.h>
 
 
 
-class KBankingSettings: public KBankingSettingsUi {
-  Q_OBJECT
+class KBankingSettings: public QBCfgTabSettings {
 private:
-  KBanking *_banking;
-  KBAccountListView *_accListView;
-  KBPluginDescrListView *_providerListView;
-
-  void _accountRescan();
-  void _backendRescan();
-
 public:
   KBankingSettings(KBanking *ab,
                    QWidget* parent = 0,
@@ -41,12 +30,6 @@ public:
 
   int init();
   int fini();
-
-public slots:
-  void slotAccountMap();
-  void slotBackendEnable();
-  void slotBackendDisable();
-  void slotBackendSetup();
 };
 
 
