@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: cryptmanager_l.h,v $
  -------------------
- cvs         : $Id: cryptmanager_l.h,v 1.1 2005/07/26 12:19:38 aquamaniac Exp $
+ cvs         : $Id: cryptmanager_l.h,v 1.2 2006/02/10 12:10:18 cstim Exp $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -19,7 +19,7 @@
 
 #include <aqbanking/banking.h>
 #include <gwenhywfar/misc.h>
-#include <gwenhywfar/misc2.h>
+#include <gwenhywfar/list2.h>
 #include <gwenhywfar/inherit.h>
 #include <gwenhywfar/crypttoken.h>
 
