@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: job.c,v $
  -------------------
- cvs         : $Id: job.c,v 1.32 2005/09/09 13:52:05 aquamaniac Exp $
+ cvs         : $Id: job.c,v 1.35 2006/02/14 02:11:53 aquamaniac Exp $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -16,6 +16,7 @@
 
 #include "job_p.h"
 #include "job_be.h"
+#include "i18n_l.h"
 #include "account_l.h"
 #include "banking_l.h"
 #include "provider_l.h"
@@ -24,16 +25,16 @@
 #include "jobs/jobgetstandingorders_l.h"
 #include "jobs/jobgetbalance_l.h"
 #include "jobs/jobtransferbase_l.h"
-#include "jobs/jobsingletransfer_be.h"
-#include "jobs/jobsingledebitnote_be.h"
+#include "jobs/jobsingletransfer_l.h"
+#include "jobs/jobsingledebitnote_l.h"
 #include "jobs/jobeutransfer_l.h"
-#include "jobs/jobcreatesto_be.h"
-#include "jobs/jobmodifysto_be.h"
-#include "jobs/jobdeletesto_be.h"
-#include "jobs/jobcreatedatedtransfer_be.h"
-#include "jobs/jobmodifydatedtransfer_be.h"
-#include "jobs/jobdeletedatedtransfer_be.h"
-#include "jobs/jobinternaltransfer_be.h"
+#include "jobs/jobcreatesto_l.h"
+#include "jobs/jobmodifysto_l.h"
+#include "jobs/jobdeletesto_l.h"
+#include "jobs/jobcreatedatedtransfer_l.h"
+#include "jobs/jobmodifydatedtransfer_l.h"
+#include "jobs/jobdeletedatedtransfer_l.h"
+#include "jobs/jobinternaltransfer_l.h"
 
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/misc.h>
@@ -214,7 +215,6 @@ const char *AB_Job_Status2Char(AB_JOB_STATUS i) {
   case AB_Job_StatusPending:  s="pending"; break;
   case AB_Job_StatusFinished: s="finished"; break;
   case AB_Job_StatusError:    s="error"; break;
-  case AB_Job_StatusDeferred: s="deferred"; break;
   default:                    s="unknown"; break;
   }
   return s;
@@ -232,7 +232,6 @@ AB_JOB_STATUS AB_Job_Char2Status(const char *s) {
   else if (strcasecmp(s, "pending")==0) i=AB_Job_StatusPending;
   else if (strcasecmp(s, "finished")==0) i=AB_Job_StatusFinished;
   else if (strcasecmp(s, "error")==0) i=AB_Job_StatusError;
-  else if (strcasecmp(s, "deferred")==0) i=AB_Job_StatusDeferred;
   else i=AB_Job_StatusUnknown;
 
   return i;
@@ -267,6 +266,33 @@ const char *AB_Job_Type2Char(AB_JOB_TYPE i) {
 
 
 
+const char *AB_Job_Type2LocalChar(AB_JOB_TYPE i) {
+  const char *s;
+
+  switch(i) {
+  case AB_Job_TypeGetBalance:          s=I18N("Get Balance"); break;
+  case AB_Job_TypeGetTransactions:     s=I18N("Get Transactions"); break;
+  case AB_Job_TypeTransfer:            s=I18N("Transfer"); break;
+  case AB_Job_TypeDebitNote:           s=I18N("Debit Note"); break;
+  case AB_Job_TypeEuTransfer:          s=I18N("EU Transfer"); break;
+  case AB_Job_TypeGetStandingOrders:   s=I18N("Get Standing Orders"); break;
+  case AB_Job_TypeGetDatedTransfers:   s=I18N("Get Dated Transfers"); break;
+  case AB_Job_TypeCreateStandingOrder: s=I18N("Create Standing Order"); break;
+  case AB_Job_TypeModifyStandingOrder: s=I18N("Modify Standing Order"); break;
+  case AB_Job_TypeDeleteStandingOrder: s=I18N("Delete Standing Order"); break;
+  case AB_Job_TypeCreateDatedTransfer: s=I18N("Create Dated Transfer"); break;
+  case AB_Job_TypeModifyDatedTransfer: s=I18N("Modify Dated Transfer"); break;
+  case AB_Job_TypeDeleteDatedTransfer: s=I18N("Delete Dated Transfer"); break;
+  case AB_Job_TypeInternalTransfer:    s=I18N("Internal Transfer"); break;
+  default:
+  case AB_Job_TypeUnknown:             s=I18N("unknown"); break;
+  }
+
+  return s;
+}
+
+
+
 AB_JOB_TYPE AB_Job_Char2Type(const char *s) {
   AB_JOB_TYPE i;
 
