@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: jobcreatedatedtransfer_be.h,v $
  -------------------
- cvs         : $Id: jobcreatedatedtransfer_be.h,v 1.1 2005/06/30 13:33:14 aquamaniac Exp $
+ cvs         : $Id: jobcreatedatedtransfer_be.h,v 1.4 2006/02/21 17:04:54 aquamaniac Exp $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -17,11 +17,29 @@
 
 #include <aqbanking/jobcreatedatedtransfer.h>
 
+/** @addtogroup G_AB_JOBS_DATED_TRANSFER_MK
+ *
+ */
+/*@{*/
 
+/** @name Backend Functions
+ *
+ * Functions in this group are only to be called by banking backends.
+ */
+/*@{*/
+
+/**
+ * This function lets the backend specify the limits for some of the fields
+ * of a @ref AB_TRANSACTION.
+ */
+AQBANKING_API
 void AB_JobCreateDatedTransfer_SetFieldLimits(AB_JOB *j,
                                               AB_TRANSACTION_LIMITS *limits);
-AB_JOB *AB_JobCreateDatedTransfer_fromDb(AB_ACCOUNT *a, GWEN_DB_NODE *db);
-int AB_JobCreateDatedTransfer_toDb(const AB_JOB *j, GWEN_DB_NODE *db);
+
+/*@}*/ 
+
+
+/*@}*/ /* addtogroup */
 
 
 #endif
