@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: jobeutransfer_p.h,v $
  -------------------
- cvs         : $Id: jobeutransfer_p.h,v 1.2 2005/03/22 23:32:52 aquamaniac Exp $
+ cvs         : $Id: jobeutransfer_p.h,v 1.3 2006/01/13 13:59:57 cstim Exp $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -26,7 +26,7 @@ struct AB_JOBEUTRANSFER {
   int ibanAllowed;
   AB_JOBEUTRANSFER_CHARGE_WHOM chargeWhom;
 };
-void AB_JobEuTransfer_FreeData(void *bp, void *p);
+static void AB_JobEuTransfer_FreeData(void *bp, void *p);
 
 
 #endif
