@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: jobgetbalance_be.h,v $
  -------------------
- cvs         : $Id: jobgetbalance_be.h,v 1.1 2004/08/16 13:26:27 aquamaniac Exp $
+ cvs         : $Id: jobgetbalance_be.h,v 1.2 2006/02/14 02:11:54 aquamaniac Exp $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -24,11 +24,6 @@ extern "C" {
 #endif
 
 
-AQBANKING_API
-void AB_JobGetBalance_SetAccountStatus(AB_JOB *j,
-                                       const AB_ACCOUNT_STATUS *as);
-
-
 #ifdef __cplusplus
 }
 #endif
