@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: jobgetdatedtransfers_l.h,v $
  -------------------
- cvs         : $Id: jobgetdatedtransfers_l.h,v 1.1 2005/06/21 00:36:45 aquamaniac Exp $
+ cvs         : $Id: jobgetdatedtransfers_l.h,v 1.2 2006/02/14 02:11:54 aquamaniac Exp $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -25,6 +25,9 @@ extern "C" {
 AB_JOB *AB_JobGetDatedTransfers_fromDb(AB_ACCOUNT *a, GWEN_DB_NODE *db);
 int AB_JobGetDatedTransfers_toDb(const AB_JOB *j, GWEN_DB_NODE *db);
 
+void AB_JobGetDatedTransfers_SetDatedTransfers(AB_JOB *j,
+                                               AB_TRANSACTION_LIST2 *tl);
+
 #ifdef __cplusplus
 }
 #endif
