@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: jobgetdatedtransfers_p.h,v $
  -------------------
- cvs         : $Id: jobgetdatedtransfers_p.h,v 1.1 2005/06/21 00:36:45 aquamaniac Exp $
+ cvs         : $Id: jobgetdatedtransfers_p.h,v 1.2 2006/01/13 13:59:57 cstim Exp $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -35,7 +35,7 @@ struct AB_JOB_GETDATEDTRANSFERS {
 
 };
 
-void AB_JobGetDatedTransfers_FreeData(void *bp, void *p);
+static void AB_JobGetDatedTransfers_FreeData(void *bp, void *p);
 
 
 
