@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: jobinternaltransfer_be.h,v $
  -------------------
- cvs         : $Id: jobinternaltransfer_be.h,v 1.1 2005/09/09 13:52:05 aquamaniac Exp $
+ cvs         : $Id: jobinternaltransfer_be.h,v 1.4 2006/02/21 17:04:54 aquamaniac Exp $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -18,11 +18,27 @@
 #include <aqbanking/jobinternaltransfer.h>
 
 
-void AB_JobInternalTransfer_SetFieldLimits(AB_JOB *j,
-                                           AB_TRANSACTION_LIMITS *limits);
-AB_JOB *AB_JobInternalTransfer_fromDb(AB_ACCOUNT *a, GWEN_DB_NODE *db);
-int AB_JobInternalTransfer_toDb(const AB_JOB *j, GWEN_DB_NODE *db);
+/** @addtogroup G_AB_JOBS_XFER_INTERNAL
+ *
+ */
+/*@{*/
 
+/** @name Backend Functions
+ *
+ * Functions in this group are only to be called by banking backends.
+ */
+/*@{*/
+
+/**
+ * This function lets the backend specify the limits for some of the fields
+ * of a @ref AB_TRANSACTION.
+ */
+AQBANKING_API void AB_JobInternalTransfer_SetFieldLimits(AB_JOB *j,
+                                           AB_TRANSACTION_LIMITS *limits);
+/*@}*/ 
+
+
+/*@}*/ /* addtogroup */
 
 #endif
 
