@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: provider_l.h,v $
  -------------------
- cvs         : $Id: provider_l.h,v 1.10 2005/05/01 13:44:27 aquamaniac Exp $
+ cvs         : $Id: provider_l.h,v 1.12 2006/02/16 21:32:19 aquamaniac Exp $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -15,13 +15,14 @@
 #define AQBANKING_PROVIDER_L_H
 
 #define AB_PROVIDER_FOLDER "providers"
-#define AB_PROVIDER_WIZARD_FOLDER "wizards"
 #define AB_PROVIDER_DEBUGGER_FOLDER "debugger"
 
 #include <aqbanking/provider.h>
 #include <aqbanking/provider_be.h>
 #include <gwenhywfar/plugin.h>
 
+GWEN_LIST_FUNCTION_DEFS(AB_PROVIDER, AB_Provider)
+
 
 void AB_Provider_SetPlugin(AB_PROVIDER *pro, GWEN_PLUGIN *pl);
 void AB_Provider_free(AB_PROVIDER *pro);
