@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: value.c,v $
                              -------------------
-    cvs         : $Id: value.c,v 1.9 2005/02/22 10:25:10 cstim Exp $
+    cvs         : $Id: value.c,v 1.11 2006/03/15 09:51:47 aquamaniac Exp $
     begin       : Mon Apr 05 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -132,8 +132,10 @@ AB_VALUE *AB_Value_fromString(const char *s){
       else if (c==':')
         break;
       else if (c!='.' && c!='-' && c!='+' && !isdigit(c)) {
-        DBG_ERROR(AQBANKING_LOGDOMAIN, "Non-digit character in value at %d (%02x)", i, c);
-        return 0;
+	DBG_ERROR(AQBANKING_LOGDOMAIN,
+		  "Non-digit character in value at %d (%02x) [%s]",
+		  i, c, origS);
+	return 0;
       }
       assert(i<sizeof(numbuf)-1);
       numbuf[i++]=c;
@@ -180,6 +182,25 @@ AB_VALUE *AB_Value_fromString(const char *s){
 
 
 
+int AB_Value_toString(const AB_VALUE *v, GWEN_BUFFER *buf) {
+  assert(v);
+  assert(buf);
+
+  if (!v->isValid)
+    return AB_ERROR_INVALID;
+  if (GWEN_Text_DoubleToBuffer(v->value, buf)) {
+    return -1;
+  }
+  if (v->currency && v->currency[0]) {
+    GWEN_Buffer_AppendString(buf, ":");
+    GWEN_Buffer_AppendString(buf, v->currency);
+  }
+
+  return 0;
+}
+
+
+
 void AB_Value_free(AB_VALUE *v){
   if (v) {
     free(v->currency);
