@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: wcb_p.h,v $
                              -------------------
-    cvs         : $Id: wcb_p.h,v 1.1 2005/03/29 20:55:59 aquamaniac Exp $
+    cvs         : $Id: wcb_p.h,v 1.2 2006/01/13 13:59:57 cstim Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -21,16 +21,18 @@ struct AB_WAITCALLBACK {
   AB_BANKING *banking;
   GWEN_TYPE_UINT64 lastProgress;
 };
-void AB_WaitCallback_FreeData(void *bp, void *p);
+static void AB_WaitCallback_FreeData(void *bp, void *p);
 
 
-GWEN_WAITCALLBACK_RESULT AB_WaitCallback_CheckAbort(GWEN_WAITCALLBACK *ctx,
-                                                    unsigned int level);
-GWEN_WAITCALLBACK *AB_WaitCallback_Instantiate(GWEN_WAITCALLBACK *ctx);
-void AB_WaitCallback_Log(GWEN_WAITCALLBACK *ctx,
-                         unsigned int level,
-                         GWEN_LOGGER_LEVEL loglevel,
-                         const char *s);
+static GWEN_WAITCALLBACK_RESULT
+  AB_WaitCallback_CheckAbort(GWEN_WAITCALLBACK *ctx,
+                             unsigned int level);
+static GWEN_WAITCALLBACK*
+  AB_WaitCallback_Instantiate(GWEN_WAITCALLBACK *ctx);
+static void AB_WaitCallback_Log(GWEN_WAITCALLBACK *ctx,
+                                unsigned int level,
+                                GWEN_LOGGER_LEVEL loglevel,
+                                const char *s);
 
 
 
