@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: job_p.h,v $
                              -------------------
-    cvs         : $Id: job_p.h,v 1.1 2005/08/08 02:24:40 aquamaniac Exp $
+    cvs         : $Id: job_p.h,v 1.2 2006/01/13 13:59:57 cstim Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -13,7 +13,7 @@
 #ifndef AD_JOB_P_H
 #define AD_JOB_P_H
 
-#include <aqdtaus/job.h>
+#include "job_l.h"
 
 
 struct AD_JOB {
