@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: card_p.h,v $
                              -------------------
-    cvs         : $Id: card_p.h,v 1.1 2005/08/08 02:24:40 aquamaniac Exp $
+    cvs         : $Id: card_p.h,v 1.2 2006/01/13 16:51:44 cstim Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -13,7 +13,7 @@
 #ifndef AG_CARD_P_H
 #define AG_CARD_P_H
 
-#include <aqgeldkarte/card.h>
+#include "card_l.h"
 
 
 struct AG_CARD {
