@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: accountjob_p.h,v $
                              -------------------
-    cvs         : $Id: accountjob_p.h,v 1.1 2005/08/08 02:24:41 aquamaniac Exp $
+    cvs         : $Id: accountjob_p.h,v 1.2 2006/01/13 13:59:58 cstim Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -20,11 +20,11 @@
 
 typedef struct AH_ACCOUNTJOB AH_ACCOUNTJOB;
 struct AH_ACCOUNTJOB {
-  AH_ACCOUNT *account;
+  AB_ACCOUNT *account;
 };
 
 
-void AH_AccountJob_FreeData(void *bp, void *p);
+static void AH_AccountJob_FreeData(void *bp, void *p);
 
 
 
