@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: jobeutransfer.c,v $
                              -------------------
-    cvs         : $Id: jobeutransfer.c,v 1.1 2005/08/08 02:24:41 aquamaniac Exp $
+    cvs         : $Id: jobeutransfer.c,v 1.4 2006/02/22 19:38:56 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -19,6 +19,8 @@
 #include "jobeutransfer_p.h"
 #include "aqhbci_l.h"
 #include "accountjob_l.h"
+#include <aqhbci/account.h>
+
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/misc.h>
 #include <gwenhywfar/inherit.h>
@@ -41,23 +43,23 @@ GWEN_INHERIT(AH_JOB, AH_JOB_EUTRANSFER);
 
 
 /* --------------------------------------------------------------- FUNCTION */
-AH_JOB *AH_Job_EuTransfer_new(AH_CUSTOMER *cu,
-                              AH_ACCOUNT *account) {
-  return AH_Job_EuTransferBase_new(cu, account, 1);
+AH_JOB *AH_Job_EuTransfer_new(AB_USER *u,
+                              AB_ACCOUNT *account) {
+  return AH_Job_EuTransferBase_new(u, account, 1);
 }
 
 
 
 /* --------------------------------------------------------------- FUNCTION */
-AH_JOB *AH_Job_EuTransferBase_new(AH_CUSTOMER *cu,
-                                  AH_ACCOUNT *account,
+AH_JOB *AH_Job_EuTransferBase_new(AB_USER *u,
+                                  AB_ACCOUNT *account,
                                   int isTransfer) {
   AH_JOB *j;
   AH_JOB_EUTRANSFER *aj;
   GWEN_DB_NODE *dbArgs;
 
   j=AH_AccountJob_new("JobEuTransfer",
-                      cu, account);
+                      u, account);
   if (!j)
     return 0;
 
@@ -91,7 +93,7 @@ void AH_Job_EuTransfer_FreeData(void *bp, void *p){
 
 
 /* --------------------------------------------------------------- FUNCTION */
-int AH_Job_EuTransfer_Process(AH_JOB *j){
+int AH_Job_EuTransfer_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_EUTRANSFER *aj;
 
   assert(j);
@@ -312,13 +314,13 @@ int AH_Job_EuTransfer__ValidateTransfer(AB_JOB *bj,
   /* check local bank code */
   s=AB_Transaction_GetLocalBankCode(t);
   if (!s) {
-    AH_ACCOUNT *a;
+    AB_ACCOUNT *a;
 
     DBG_WARN(AQHBCI_LOGDOMAIN,
 	     "No local bank code, filling in");
     a=AH_AccountJob_GetAccount(mj);
     assert(a);
-    s=AH_Account_GetBankId(a);
+    s=AB_Account_GetBankCode(a);
     assert(s);
     AB_Transaction_SetLocalBankCode(t, s);
   }
@@ -326,13 +328,13 @@ int AH_Job_EuTransfer__ValidateTransfer(AB_JOB *bj,
   /* check local account number */
   s=AB_Transaction_GetLocalAccountNumber(t);
   if (!s) {
-    AH_ACCOUNT *a;
+    AB_ACCOUNT *a;
 
     DBG_WARN(AQHBCI_LOGDOMAIN,
 	     "No local account number, filling in");
     a=AH_AccountJob_GetAccount(mj);
     assert(a);
-    s=AH_Account_GetAccountId(a);
+    s=AB_Account_GetAccountNumber(a);
     assert(s);
     AB_Transaction_SetLocalAccountNumber(t, s);
   }
@@ -340,7 +342,7 @@ int AH_Job_EuTransfer__ValidateTransfer(AB_JOB *bj,
   /* check local account suffix */
   s=AB_Transaction_GetLocalSuffix(t);
   if (!s) {
-    AH_ACCOUNT *a;
+    AB_ACCOUNT *a;
 
     DBG_INFO(AQHBCI_LOGDOMAIN,
 	     "No local suffix, filling in (if possible)");
