@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: jobgetbalance_p.h,v $
                              -------------------
-    cvs         : $Id: jobgetbalance_p.h,v 1.1 2005/08/08 02:24:41 aquamaniac Exp $
+    cvs         : $Id: jobgetbalance_p.h,v 1.4 2006/02/22 19:38:56 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -15,20 +15,20 @@
 #define AH_JOBGETBALANCE_P_H
 
 
-#include <aqhbci/jobgetbalance.h>
+#include "jobgetbalance_l.h"
 #include <gwenhywfar/db.h>
 
 
 typedef struct AH_JOB_GETBALANCE AH_JOB_GETBALANCE;
 struct AH_JOB_GETBALANCE {
-  AB_ACCOUNT_STATUS *accountStatus;
+  int dummy;
 };
-void AH_Job_GetBalance_FreeData(void *bp, void *p);
-int AH_Job_GetBalance_Process(AH_JOB *j);
-int AH_Job_GetBalance_Exchange(AH_JOB *j, AB_JOB *bj,
-                               AH_JOB_EXCHANGE_MODE m);
+static void AH_Job_GetBalance_FreeData(void *bp, void *p);
+static int AH_Job_GetBalance_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx);
+static int AH_Job_GetBalance_Exchange(AH_JOB *j, AB_JOB *bj,
+                                      AH_JOB_EXCHANGE_MODE m);
 
-AB_BALANCE *AH_Job_GetBalance__ReadBalance(GWEN_DB_NODE *dbT);
+static AB_BALANCE *AH_Job_GetBalance__ReadBalance(GWEN_DB_NODE *dbT);
 
 
 
