@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: jobgetdatedxfers_p.h,v $
                              -------------------
-    cvs         : $Id: jobgetdatedxfers_p.h,v 1.1 2005/08/08 02:24:41 aquamaniac Exp $
+    cvs         : $Id: jobgetdatedxfers_p.h,v 1.4 2006/02/22 19:38:56 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -15,19 +15,20 @@
 #define AH_JOBGETDATEDTRANSFERS_P_H
 
 
-#include <aqhbci/jobgetdatedxfers.h>
+#include "jobgetdatedxfers_l.h"
 #include <gwenhywfar/db.h>
 
 
 typedef struct AH_JOB_GETDATEDTRANSFERS AH_JOB_GETDATEDTRANSFERS;
 struct AH_JOB_GETDATEDTRANSFERS {
-  AB_TRANSACTION_LIST2 *datedTransfers;
+  int dummy;
 };
-void AH_Job_GetDatedTransfers_FreeData(void *bp, void *p);
+static void AH_Job_GetDatedTransfers_FreeData(void *bp, void *p);
 
-int AH_Job_GetDatedTransfers_Process(AH_JOB *j);
-int AH_Job_GetDatedTransfers_Exchange(AH_JOB *j, AB_JOB *bj,
-                                      AH_JOB_EXCHANGE_MODE m);
+static int AH_Job_GetDatedTransfers_Process(AH_JOB *j,
+                                            AB_IMEXPORTER_CONTEXT *ctx);
+static int AH_Job_GetDatedTransfers_Exchange(AH_JOB *j, AB_JOB *bj,
+                                             AH_JOB_EXCHANGE_MODE m);
 
 
 #endif /* AH_JOBGETDATEDTRANSFERS_P_H */
