@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: outbox.c,v $
                              -------------------
-    cvs         : $Id: outbox.c,v 1.4 2005/09/17 08:11:25 cstim Exp $
+    cvs         : $Id: outbox.c,v 1.9 2006/02/22 19:38:58 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -22,12 +22,14 @@
 #include "accountjob_l.h"
 #include "jobqueue_l.h"
 #include "hbci_l.h"
-#include "adminjobs.h"
+#include "adminjobs_l.h"
+#include "dialog_l.h"
 #include "jobmultitransfer_l.h"
+#include <aqhbci/provider.h>
 #include <aqbanking/job_be.h>
+#include <aqbanking/banking_be.h>
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/misc.h>
-#include <gwenhywfar/net.h>
 #include <gwenhywfar/waitcallback.h>
 
 #include <stdlib.h>
@@ -41,17 +43,17 @@ GWEN_LIST_FUNCTIONS(AH_OUTBOX__CBOX, AH_Outbox__CBox);
 
 
 
-AH_OUTBOX__CBOX *AH_Outbox__CBox_new(AH_HBCI *hbci, AH_CUSTOMER *cu,
-				     AH_OUTBOX *ob) {
+AH_OUTBOX__CBOX *AH_Outbox__CBox_new(AH_HBCI *hbci,
+                                     AB_USER *u,
+                                     AH_OUTBOX *ob) {
   AH_OUTBOX__CBOX *cbox;
 
   assert(hbci);
-  assert(cu);
+  assert(u);
   GWEN_NEW_OBJECT(AH_OUTBOX__CBOX, cbox);
   cbox->usage=1;
   GWEN_LIST_INIT(AH_OUTBOX__CBOX, cbox);
-  cbox->customer=cu;
-  AH_Customer_Attach(cu);
+  cbox->user=u;
   cbox->todoQueues=AH_JobQueue_List_new();
   cbox->finishedQueues=AH_JobQueue_List_new();
   cbox->todoJobs=AH_Job_List_new();
@@ -74,7 +76,6 @@ void AH_Outbox__CBox_free(AH_OUTBOX__CBOX *cbox){
       AH_JobQueue_List_free(cbox->finishedQueues);
       AH_Job_List_free(cbox->todoJobs);
       AH_Job_List_free(cbox->finishedJobs);
-      AH_Customer_free(cbox->customer);
 
       GWEN_FREE_OBJECT(cbox);
     }
@@ -83,13 +84,6 @@ void AH_Outbox__CBox_free(AH_OUTBOX__CBOX *cbox){
 
 
 
-void AH_Outbox__CBox_Attach(AH_OUTBOX__CBOX *cbox){
-  assert(cbox);
-  cbox->usage++;
-}
-
-
-
 void AH_Outbox__CBox_AddTodoJob(AH_OUTBOX__CBOX *cbox, AH_JOB *j) {
   assert(cbox);
   assert(j);
@@ -109,13 +103,6 @@ void AH_Outbox__CBox_AddPendingJob(AH_OUTBOX__CBOX *cbox, AB_JOB *bj) {
 
 
 
-AB_JOB_LIST2 *AH_Outbox__CBox_GetPendingJobs(const AH_OUTBOX__CBOX *cbox){
-  assert(cbox);
-  return cbox->pendingJobs;
-}
-
-
-
 int AH_Outbox__CBox_CheckPending(AH_OUTBOX__CBOX *cbox) {
   AH_JOB *j;
 
@@ -314,16 +301,14 @@ void AH_Outbox__CBox_Finish(AH_OUTBOX__CBOX *cbox){
 
 
 
-AH_CUSTOMER*
-AH_Outbox__CBox_GetCustomer(const AH_OUTBOX__CBOX *cbox){
+AB_USER *AH_Outbox__CBox_GetUser(const AH_OUTBOX__CBOX *cbox){
   assert(cbox);
-  return cbox->customer;
+  return cbox->user;
 }
 
 
 
-AH_JOB_LIST*
-AH_Outbox__CBox_TakeFinishedJobs(AH_OUTBOX__CBOX *cbox){
+AH_JOB_LIST *AH_Outbox__CBox_TakeFinishedJobs(AH_OUTBOX__CBOX *cbox){
   AH_JOB_LIST *jl;
 
   assert(cbox);
@@ -438,16 +423,12 @@ int AH_Outbox__CBox_Prepare(AH_OUTBOX__CBOX *cbox){
     DBG_INFO(AQHBCI_LOGDOMAIN, "Will ask for status reports");
     t1=AH_Outbox__CBox_GetEarliestPendingDate(cbox);
     t2=AH_Outbox__CBox_GetLatestPendingDate(cbox);
-    sj=AH_Job_GetStatus_new(cbox->customer, t1, t2);
+    sj=AH_Job_GetStatus_new(cbox->user, t1, t2);
     GWEN_Time_free(t2);
     GWEN_Time_free(t1);
     if (sj) {
-      AH_USER *u;
-
       AH_Job_AddFlags(sj, AH_JOB_FLAGS_OUTBOX);
-      u=AH_Customer_GetUser(cbox->customer);
-      assert(u);
-      AH_Job_AddSigner(sj, AH_User_GetUserId(u));
+      AH_Job_AddSigner(sj, AB_User_GetUserId(cbox->user));
       AH_Outbox__CBox_AddTodoJob(cbox, sj);
     }
     else {
@@ -472,7 +453,7 @@ int AH_Outbox__CBox_Prepare(AH_OUTBOX__CBOX *cbox){
 
         DBG_INFO(AQHBCI_LOGDOMAIN, "Preparing dialog job \"%s\"",
                  AH_Job_GetName(j));
-        jq=AH_JobQueue_new(cbox->customer);
+        jq=AH_JobQueue_new(cbox->user);
         AH_Job_List_Del(j);
         if (AH_JobQueue_AddJob(jq, j)!=AH_JobQueueAddResultOk) {
           /* error adding a single job to the queue */
@@ -509,7 +490,7 @@ int AH_Outbox__CBox_Prepare(AH_OUTBOX__CBOX *cbox){
   /* now todoJobs only contains non-dialog jobs with a correct status,
    * append them to new queues as needed */
   DBG_INFO(AQHBCI_LOGDOMAIN, "Preparing non-dialog jobs");
-  jq=AH_JobQueue_new(cbox->customer);
+  jq=AH_JobQueue_new(cbox->user);
   AH_JobQueue_AddFlags(jq, AH_JOBQUEUE_FLAGS_BEGINDIALOG);
   firstJob=1;
   DBG_INFO(AQHBCI_LOGDOMAIN, "We have %d jobs to handle",
@@ -552,7 +533,7 @@ int AH_Outbox__CBox_Prepare(AH_OUTBOX__CBOX *cbox){
              * a new queue */
             DBG_INFO(AQHBCI_LOGDOMAIN, "Queue full, starting next one");
             AH_JobQueue_List_Add(jq, cbox->todoQueues);
-            jq=AH_JobQueue_new(cbox->customer);
+            jq=AH_JobQueue_new(cbox->user);
             firstJob=1;
 	    queueCreated=1;
 	    /* put job back into queue (same pos, try it again in next loop)*/
@@ -609,7 +590,7 @@ int AH_Outbox__CBox_Prepare(AH_OUTBOX__CBOX *cbox){
       /* there are some retry jobs, retry them */
       if (AH_JobQueue_GetCount(jq)!=0) {
 	AH_JobQueue_List_Add(jq, cbox->todoQueues);
-	jq=AH_JobQueue_new(cbox->customer);
+	jq=AH_JobQueue_new(cbox->user);
 	firstJob=1;
 	queueCreated=1;
       }
@@ -685,10 +666,7 @@ int AH_Outbox__CBox_SendQueue(AH_OUTBOX__CBOX *cbox, int timeout,
 			 0,
 			 AB_Banking_LogLevelInfo,
                          I18N("Sending queue"));
-  if (timeout==GWEN_NETCONNECTION_TIMEOUT_NONE)
-    rv=AH_Dialog_SendMessage(dlg, msg);
-  else
-    rv=AH_Dialog_SendMessage_Wait(dlg, msg, timeout);
+  rv=AH_Dialog_SendMessage_Wait(dlg, msg, timeout);
   if (rv) {
     DBG_NOTICE(AQHBCI_LOGDOMAIN, "Could not send message");
     AB_Banking_ProgressLog(AH_HBCI_GetBankingApi(cbox->hbci),
@@ -708,32 +686,10 @@ int AH_Outbox__CBox_RecvQueue(AH_OUTBOX__CBOX *cbox,
 			      AH_DIALOG *dlg,
 			      AH_JOBQUEUE *jq){
   AH_MSG *msg;
-  time_t startt;
-  int distance;
-  AH_USER *u;
-  AH_BANK *b;
   GWEN_DB_NODE *rsp;
   int rv;
 
   assert(cbox);
-  u=AH_Customer_GetUser(cbox->customer);
-  assert(u);
-  b=AH_User_GetBank(u);
-  assert(b);
-
-  startt=time(0);
-  if (timeout==GWEN_NETCONNECTION_TIMEOUT_NONE)
-    distance=GWEN_NETCONNECTION_TIMEOUT_NONE;
-  else if (timeout==GWEN_NETCONNECTION_TIMEOUT_FOREVER)
-    distance=GWEN_NETCONNECTION_TIMEOUT_FOREVER;
-  else {
-    distance=AH_OUTBOX_TIME_DISTANCE;
-    if (distance)
-      if ((distance/1000)>timeout)
-        distance=timeout*1000;
-    if (!distance)
-      distance=750;
-  }
 
   AB_Banking_ProgressLog(AH_HBCI_GetBankingApi(cbox->hbci),
 			 0,
@@ -833,7 +789,6 @@ int AH_Outbox__CBox_SendAndRecvQueue(AH_OUTBOX__CBOX *cbox,
     return rv;
   }
 
-
   return 0;
 }
 
@@ -853,21 +808,20 @@ int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
     /* sign and crypt, not anonymous */
     DBG_NOTICE(AQHBCI_LOGDOMAIN,
 	       "Creating non-anonymous dialog open request");
-    jDlgOpen=AH_Job_new("JobDialogInit", cbox->customer, 0);
+    jDlgOpen=AH_Job_new("JobDialogInit", cbox->user, 0);
     if (!jDlgOpen) {
       DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not create job JobDialogInit");
       return AB_ERROR_GENERIC;
     }
     if (jqFlags & AH_JOBQUEUE_FLAGS_SIGN)
       AH_Job_AddSigner(jDlgOpen,
-		       AH_User_GetUserId(AH_Customer_GetUser(cbox->customer)));
-    /* was before: AH_Customer_GetCustomerId(cbox->customer)); */
+                       AB_User_GetUserId(cbox->user));
     AH_Dialog_SubFlags(dlg, AH_DIALOG_FLAGS_ANONYMOUS);
   }
   else {
     /* neither sign nor crypt, use anonymous dialog */
     DBG_NOTICE(AQHBCI_LOGDOMAIN, "Creating anonymous dialog open request");
-    jDlgOpen=AH_Job_new("JobDialogInitAnon", cbox->customer, 0);
+    jDlgOpen=AH_Job_new("JobDialogInitAnon", cbox->user, 0);
     if (!jDlgOpen) {
       DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not create job JobDialogInitAnon");
       return AB_ERROR_GENERIC;
@@ -879,7 +833,7 @@ int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
                          0,
                          AB_Banking_LogLevelNotice,
 			 I18N("Opening dialog"));
-  jqDlgOpen=AH_JobQueue_new(cbox->customer);
+  jqDlgOpen=AH_JobQueue_new(cbox->user);
   AH_JobQueue_AddFlags(jqDlgOpen, AH_JOBQUEUE_FLAGS_OUTBOX);
   DBG_NOTICE(AQHBCI_LOGDOMAIN, "Enqueueing dialog open request");
   if (AH_JobQueue_AddJob(jqDlgOpen, jDlgOpen)!=
@@ -917,15 +871,8 @@ int AH_Outbox__CBox_CloseDialog(AH_OUTBOX__CBOX *cbox,
   AH_JOB *jDlgClose;
   GWEN_DB_NODE *db;
   GWEN_TYPE_UINT32 dlgFlags;
-  AH_USER *u;
-  AH_BANK *b;
   int rv;
 
-  u=AH_Customer_GetUser(cbox->customer);
-  assert(u);
-  b=AH_User_GetBank(u);
-  assert(b);
-
   AB_Banking_ProgressLog(AH_HBCI_GetBankingApi(cbox->hbci),
 			 0,
 			 AB_Banking_LogLevelNotice,
@@ -933,7 +880,7 @@ int AH_Outbox__CBox_CloseDialog(AH_OUTBOX__CBOX *cbox,
   DBG_NOTICE(AQHBCI_LOGDOMAIN, "Sending dialog close request (flags=%08x)",
 	     jqFlags);
   dlgFlags=AH_Dialog_GetFlags(dlg);
-  jDlgClose=AH_Job_new("JobDialogEnd", cbox->customer, 0);
+  jDlgClose=AH_Job_new("JobDialogEnd", cbox->user, 0);
   if (!jDlgClose) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not create job JobDialogEnd");
     return AB_ERROR_GENERIC;
@@ -950,12 +897,12 @@ int AH_Outbox__CBox_CloseDialog(AH_OUTBOX__CBOX *cbox,
   if (!(dlgFlags & AH_DIALOG_FLAGS_ANONYMOUS)) {
     /* sign and encrypt job */
     DBG_INFO(AQHBCI_LOGDOMAIN, "Will encrypt and sign dialog close request");
-    AH_Job_AddSigner(jDlgClose, AH_User_GetUserId(u));
+    AH_Job_AddSigner(jDlgClose, AB_User_GetUserId(cbox->user));
     AH_Job_AddFlags(jDlgClose,
 		    AH_JOB_FLAGS_CRYPT |
 		    AH_JOB_FLAGS_SIGN);
   }
-  jqDlgClose=AH_JobQueue_new(cbox->customer);
+  jqDlgClose=AH_JobQueue_new(cbox->user);
 
   DBG_NOTICE(AQHBCI_LOGDOMAIN, "Adding dialog close request to queue");
   if (AH_JobQueue_AddJob(jqDlgClose, jDlgClose)!=
@@ -1022,16 +969,11 @@ int AH_Outbox__CBox_PerformQueue(AH_OUTBOX__CBOX *cbox,
     GWEN_TYPE_UINT32 jqFlags;
     AH_JOB *j;
     AH_JOB_LIST *jl;
-    int finishedJobs;
-    int finishedJobsBefore;
-    int i;
-
-    finishedJobsBefore=AH_Outbox_CountFinishedJobs(cbox->outbox);
 
     jobsTodo=0;
     jl=AH_JobQueue_TakeJobList(jq);
     assert(jl);
-    jqTodo=AH_JobQueue_new(AH_JobQueue_GetCustomer(jq));
+    jqTodo=AH_JobQueue_new(AH_JobQueue_GetUser(jq));
     /* copy some flags */
     jqFlags=AH_JobQueue_GetFlags(jq);
     jqFlags&=~(AH_JOBQUEUE_FLAGS_CRYPT |
@@ -1107,19 +1049,6 @@ int AH_Outbox__CBox_PerformQueue(AH_OUTBOX__CBOX *cbox,
     AH_JobQueue_free(jq);
     jq=jqTodo;
 
-    finishedJobs=AH_Outbox_CountFinishedJobs(cbox->outbox)-finishedJobsBefore;
-    DBG_NOTICE(AQHBCI_LOGDOMAIN, "Finished jobs: %d", finishedJobs);
-    for (i=0; i<finishedJobs; i++) {
-      int rv;
-
-      rv=AB_Banking_ProgressAdvance(AH_HBCI_GetBankingApi(cbox->hbci), 0,
-                                    AB_BANKING_PROGRESS_ONE);
-      if (rv) {
-        DBG_ERROR(AQHBCI_LOGDOMAIN, "User aborted");
-        return rv;
-      }
-    }
-
     if (!jobsTodo)
       break;
 
@@ -1143,30 +1072,25 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
 					   AH_JOBQUEUE_LIST *jql){
   AH_DIALOG *dlg;
   AH_JOBQUEUE *jq;
-  AH_USER *u;
-  AH_BANK *b;
   int rv;
   GWEN_TYPE_UINT32 jqflags;
 
-  u=AH_Customer_GetUser(cbox->customer);
-  assert(u);
-  b=AH_User_GetBank(u);
-  assert(b);
-
   if (AH_JobQueue_List_GetCount(jql)==0) {
     DBG_NOTICE(AQHBCI_LOGDOMAIN, "No queues to handle, doing nothing");
     AH_JobQueue_List_free(jql);
     return 0;
   }
 
-  rv=AH_HBCI_BeginDialog(cbox->hbci, cbox->customer, &dlg);
+  dlg=AH_Dialog_new(cbox->user);
+  rv=AH_Dialog_Connect(dlg, AH_HBCI_GetConnectTimeout(cbox->hbci));
   if (rv) {
     DBG_INFO(AQHBCI_LOGDOMAIN,
              "Could not begin a dialog for customer \"%s\" (%d)",
-             AH_Customer_GetCustomerId(cbox->customer), rv);
+             AB_User_GetCustomerId(cbox->user), rv);
     /* finish all queues */
     AH_Outbox__CBox_HandleQueueListError(cbox, jql,
                                          "Could not begin dialog");
+    AH_Dialog_free(dlg);
     return rv;
   }
   assert(dlg);
@@ -1178,10 +1102,11 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
   rv=AH_Outbox__CBox_OpenDialog(cbox, timeout, dlg, jqflags);
   if (rv) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Could not open dialog");
-    AH_HBCI_EndDialog(cbox->hbci, dlg);
+    AH_Dialog_Disconnect(dlg, 2);
     /* finish all queues */
     AH_Outbox__CBox_HandleQueueListError(cbox, jql,
                                          "Could not open dialog");
+    AH_Dialog_free(dlg);
     return rv;
   }
 
@@ -1198,7 +1123,8 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
     /* finish all remaining queues */
     AH_Outbox__CBox_HandleQueueListError(cbox, jql,
                                          "Could not send ");
-    AH_HBCI_EndDialog(cbox->hbci, dlg);
+    AH_Dialog_Disconnect(dlg, 2);
+    AH_Dialog_free(dlg);
     return rv;
   }
 
@@ -1212,7 +1138,8 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
   }
 
   DBG_INFO(AQHBCI_LOGDOMAIN, "Closing connection");
-  AH_HBCI_EndDialog(cbox->hbci, dlg);
+  AH_Dialog_Disconnect(dlg, 2);
+  AH_Dialog_free(dlg);
 
   AH_JobQueue_List_free(jql);
   return 0;
@@ -1224,24 +1151,19 @@ int AH_Outbox__CBox_PerformDialogQueue(AH_OUTBOX__CBOX *cbox,
 				       int timeout,
 				       AH_JOBQUEUE *jq){
   AH_DIALOG *dlg;
-  AH_USER *u;
-  AH_BANK *b;
   int rv;
 
-  u=AH_Customer_GetUser(cbox->customer);
-  assert(u);
-  b=AH_User_GetBank(u);
-  assert(b);
-
   /* open connection */
-  rv=AH_HBCI_BeginDialog(cbox->hbci, cbox->customer, &dlg);
+  dlg=AH_Dialog_new(cbox->user);
+  rv=AH_Dialog_Connect(dlg, AH_HBCI_GetConnectTimeout(cbox->hbci));
   if (rv) {
     DBG_INFO(AQHBCI_LOGDOMAIN,
              "Could not begin a dialog for customer \"%s\" (%d)",
-             AH_Customer_GetCustomerId(cbox->customer), rv);
+             AB_User_GetCustomerId(cbox->user), rv);
     /* finish all queues */
     AH_Outbox__CBox_HandleQueueError(cbox, jq,
-                                    "Could not begin dialog");
+                                     "Could not begin dialog");
+    AH_Dialog_free(dlg);
     return rv;
   }
   assert(dlg);
@@ -1249,13 +1171,15 @@ int AH_Outbox__CBox_PerformDialogQueue(AH_OUTBOX__CBOX *cbox,
   /* handle queue */
   rv=AH_Outbox__CBox_PerformQueue(cbox, dlg, jq, timeout);
   if (rv) {
-    AH_HBCI_EndDialog(cbox->hbci, dlg);
+    AH_Dialog_Disconnect(dlg, 2);
+    AH_Dialog_free(dlg);
     return rv;
   }
 
   /* close connection */
   DBG_INFO(AQHBCI_LOGDOMAIN, "Closing connection");
-  AH_HBCI_EndDialog(cbox->hbci, dlg);
+  AH_Dialog_Disconnect(dlg, 2);
+  AH_Dialog_free(dlg);
 
   return 0;
 }
@@ -1459,7 +1383,7 @@ AH_OUTBOX *AH_Outbox_new(AH_HBCI *hbci) {
   GWEN_INHERIT_INIT(AH_OUTBOX, ob);
 
   ob->hbci=hbci;
-  ob->customerBoxes=AH_Outbox__CBox_List_new();
+  ob->userBoxes=AH_Outbox__CBox_List_new();
   ob->finishedJobs=AH_Job_List_new();
   ob->usage=1;
   return ob;
@@ -1471,7 +1395,7 @@ void AH_Outbox_free(AH_OUTBOX *ob){
   if (ob) {
     assert(ob->usage);
     if (--(ob->usage)==0) {
-      AH_Outbox__CBox_List_free(ob->customerBoxes);
+      AH_Outbox__CBox_List_free(ob->userBoxes);
       AH_Job_List_free(ob->finishedJobs);
       GWEN_INHERIT_FINI(AH_OUTBOX, ob);
       GWEN_FREE_OBJECT(ob);
@@ -1497,20 +1421,20 @@ int AH_Outbox_Prepare(AH_OUTBOX *ob){
   assert(ob);
 
   errors=0;
-  cbox=AH_Outbox__CBox_List_First(ob->customerBoxes);
+  cbox=AH_Outbox__CBox_List_First(ob->userBoxes);
   while(cbox) {
-    AH_CUSTOMER *cu;
+    AB_USER *u;
 
-    cu=AH_Outbox__CBox_GetCustomer(cbox);
+    u=AH_Outbox__CBox_GetUser(cbox);
     DBG_INFO(AQHBCI_LOGDOMAIN, "Preparing queues for customer \"%s\"",
-             AH_Customer_GetCustomerId(cu));
+             AB_User_GetCustomerId(u));
     if (AH_Outbox__CBox_Prepare(cbox)) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Error preparing cbox");
       errors++;
     }
     else {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Preparing queues for customer \"%s\": done",
-               AH_Customer_GetCustomerId(cu));
+               AB_User_GetCustomerId(u));
     }
     cbox=AH_Outbox__CBox_List_Next(cbox);
   } /* while */
@@ -1525,23 +1449,23 @@ int AH_Outbox_Prepare(AH_OUTBOX *ob){
 
 
 
-AH_OUTBOX__CBOX *AH_Outbox__FindCBox(const AH_OUTBOX *ob,
-				     const AH_CUSTOMER *cu) {
+static AH_OUTBOX__CBOX *AH_Outbox__FindCBox(const AH_OUTBOX *ob,
+                                            const AB_USER *u) {
   AH_OUTBOX__CBOX *cbox;
 
   assert(ob);
-  assert(cu);
-  cbox=AH_Outbox__CBox_List_First(ob->customerBoxes);
+  assert(u);
+  cbox=AH_Outbox__CBox_List_First(ob->userBoxes);
   while(cbox) {
-    if (AH_Outbox__CBox_GetCustomer(cbox)==cu) {
+    if (AH_Outbox__CBox_GetUser(cbox)==u) {
       DBG_DEBUG(AQHBCI_LOGDOMAIN, "CBox for customer \"%s\" found",
-                AH_Customer_GetCustomerId(cu));
+                AB_User_GetCustomerId(u));
       return cbox;
     }
     cbox=AH_Outbox__CBox_List_Next(cbox);
   } /* while */
   DBG_INFO(AQHBCI_LOGDOMAIN, "CBox for customer \"%s\" not found",
-           AH_Customer_GetCustomerId(cu));
+           AB_User_GetCustomerId(u));
   return 0;
 }
 
@@ -1550,21 +1474,21 @@ AH_OUTBOX__CBOX *AH_Outbox__FindCBox(const AH_OUTBOX *ob,
 
 
 void AH_Outbox_AddJob(AH_OUTBOX *ob, AH_JOB *j){
-  AH_CUSTOMER *cu;
+  AB_USER *u;
   AH_OUTBOX__CBOX *cbox;
 
   assert(ob);
   assert(j);
 
-  cu=AH_Job_GetCustomer(j);
-  assert(cu);
+  u=AH_Job_GetUser(j);
+  assert(u);
 
-  cbox=AH_Outbox__FindCBox(ob, cu);
+  cbox=AH_Outbox__FindCBox(ob, u);
   if (!cbox) {
     DBG_NOTICE(AQHBCI_LOGDOMAIN, "Creating CBox for customer \"%s\"",
-               AH_Customer_GetCustomerId(cu));
-    cbox=AH_Outbox__CBox_new(ob->hbci, cu, ob);
-    AH_Outbox__CBox_List_Add(cbox, ob->customerBoxes);
+               AB_User_GetCustomerId(u));
+    cbox=AH_Outbox__CBox_new(ob->hbci, u, ob);
+    AH_Outbox__CBox_List_Add(cbox, ob->userBoxes);
   }
   /* attach to job so that it will never be destroyed from me */
   AH_Job_Attach(j);
@@ -1574,7 +1498,7 @@ void AH_Outbox_AddJob(AH_OUTBOX *ob, AH_JOB *j){
 
 
 void AH_Outbox_AddPendingJob(AH_OUTBOX *ob, AB_JOB *bj){
-  AH_CUSTOMER *cu;
+  AB_USER *u;
   AH_OUTBOX__CBOX *cbox;
   GWEN_DB_NODE *db;
   const char *customerId;
@@ -1592,20 +1516,21 @@ void AH_Outbox_AddPendingJob(AH_OUTBOX *ob, AB_JOB *bj){
     return;
   }
 
-  cu=AH_HBCI_FindCustomer(ob->hbci, 0, bankId, "*", customerId);
-  if (!cu) {
+  u=AB_Banking_FindUser(AH_HBCI_GetBankingApi(ob->hbci),
+                        AH_PROVIDER_NAME, 0, bankId, "*", customerId);
+  if (!u) {
     DBG_ERROR(AQHBCI_LOGDOMAIN,
               "Customer %s at bank %s not found",
               customerId, bankId);
     return;
   }
 
-  cbox=AH_Outbox__FindCBox(ob, cu);
+  cbox=AH_Outbox__FindCBox(ob, u);
   if (!cbox) {
     DBG_NOTICE(AQHBCI_LOGDOMAIN, "Creating CBox for customer \"%s\"",
-               AH_Customer_GetCustomerId(cu));
-    cbox=AH_Outbox__CBox_new(ob->hbci, cu, ob);
-    AH_Outbox__CBox_List_Add(cbox, ob->customerBoxes);
+               AB_User_GetCustomerId(u));
+    cbox=AH_Outbox__CBox_new(ob->hbci, u, ob);
+    AH_Outbox__CBox_List_Add(cbox, ob->userBoxes);
   }
   AH_Outbox__CBox_AddPendingJob(cbox, bj);
 }
@@ -1635,7 +1560,7 @@ void AH_Outbox__FinishCBox(AH_OUTBOX *ob, AH_OUTBOX__CBOX *cbox){
     AH_Job_List_Del(j);
     st=AH_Job_GetStatus(j);
     if (st==AH_JobStatusAnswered) {
-      rv=AH_Job_Process(j);
+      rv=AH_Job_Process(j, ob->context);
       if (rv) {
         char buf[256];
 
@@ -1667,11 +1592,11 @@ void AH_Outbox__FinishCBox(AH_OUTBOX *ob, AH_OUTBOX__CBOX *cbox){
 
 
 
-void AH_Outbox__FinishOutbox(AH_OUTBOX *ob) {
+static void AH_Outbox__FinishOutbox(AH_OUTBOX *ob) {
   AH_OUTBOX__CBOX *cbox;
 
   assert(ob);
-  while((cbox=AH_Outbox__CBox_List_First(ob->customerBoxes))) {
+  while((cbox=AH_Outbox__CBox_List_First(ob->userBoxes))) {
     AH_Outbox__FinishCBox(ob, cbox);
     AH_Outbox__CBox_List_Del(cbox);
     AH_Outbox__CBox_free(cbox);
@@ -1686,13 +1611,13 @@ int AH_Outbox_SendAndRecv(AH_OUTBOX *ob, int timeout){
   int errors;
 
   errors=0;
-  while((cbox=AH_Outbox__CBox_List_First(ob->customerBoxes))) {
-    AH_CUSTOMER *cu;
+  while((cbox=AH_Outbox__CBox_List_First(ob->userBoxes))) {
+    AB_USER *u;
 
-    cu=AH_Outbox__CBox_GetCustomer(cbox);
+    u=AH_Outbox__CBox_GetUser(cbox);
     DBG_INFO(AQHBCI_LOGDOMAIN,
-	     "Sending next message for customer \"%s\"",
-	     AH_Customer_GetCustomerId(cu));
+             "Sending next message for customer \"%s\"",
+             AB_User_GetCustomerId(u));
 
     rv=AH_Outbox__CBox_SendAndRecvBox(cbox, timeout);
     AH_Outbox__FinishCBox(ob, cbox);
@@ -1712,18 +1637,6 @@ int AH_Outbox_SendAndRecv(AH_OUTBOX *ob, int timeout){
 
 
 
-AH_JOB_LIST *AH_Outbox_TakeFinishedJobs(AH_OUTBOX *ob){
-  AH_JOB_LIST *jl;
-
-  assert(ob);
-  AH_Outbox__FinishOutbox(ob);
-  jl=ob->finishedJobs;
-  ob->finishedJobs=AH_Job_List_new();
-  return jl;
-}
-
-
-
 AH_JOB_LIST *AH_Outbox_GetFinishedJobs(AH_OUTBOX *ob){
   assert(ob);
   AH_Outbox__FinishOutbox(ob);
@@ -1778,7 +1691,7 @@ void AH_Outbox_Process(AH_OUTBOX *ob){
       /* only process answered jobs */
       DBG_DEBUG(AQHBCI_LOGDOMAIN,
 		"Processing job \"%s\"", AH_Job_GetName(j));
-      rv=AH_Job_Process(j);
+      rv=AH_Job_Process(j, ob->context);
       if (rv) {
 	char buf[256];
 
@@ -1812,7 +1725,7 @@ unsigned int AH_Outbox_CountTodoJobs(AH_OUTBOX *ob){
 
   assert(ob);
   cnt=0;
-  cbox=AH_Outbox__CBox_List_First(ob->customerBoxes);
+  cbox=AH_Outbox__CBox_List_First(ob->userBoxes);
   while(cbox) {
     AH_JOBQUEUE *jq;
 
@@ -1872,7 +1785,7 @@ unsigned int AH_Outbox_CountFinishedJobs(AH_OUTBOX *ob){
 
   cnt+=AH_Outbox__CountJobList(ob->finishedJobs);
 
-  cbox=AH_Outbox__CBox_List_First(ob->customerBoxes);
+  cbox=AH_Outbox__CBox_List_First(ob->userBoxes);
   while(cbox) {
     AH_JOBQUEUE *jq;
 
@@ -1912,10 +1825,7 @@ unsigned int AH_Outbox_CountFinishedJobs(AH_OUTBOX *ob){
 int AH_Outbox__Execute(AH_OUTBOX *ob){
   unsigned int loop;
   unsigned int jobCount;
-  unsigned int finishedJobs;
-  unsigned int finishedJobsBefore;
   int rv;
-  int i;
 
   assert(ob);
   jobCount=AH_Outbox_CountTodoJobs(ob);
@@ -1924,8 +1834,6 @@ int AH_Outbox__Execute(AH_OUTBOX *ob){
     return 0;
   }
 
-  finishedJobsBefore=AH_Outbox_CountFinishedJobs(ob);
-
   AB_Banking_ProgressLog(AH_HBCI_GetBankingApi(ob->hbci),
                          0,
                          AB_Banking_LogLevelNotice,
@@ -1944,17 +1852,11 @@ int AH_Outbox__Execute(AH_OUTBOX *ob){
     return rv;
   }
 
-  finishedJobs=AH_Outbox_CountFinishedJobs(ob)-finishedJobsBefore;
-  DBG_NOTICE(AQHBCI_LOGDOMAIN, "Finished jobs: %d", finishedJobs);
-  for (i=0; i<finishedJobs; i++) {
-    int rv;
-
-    rv=AB_Banking_ProgressAdvance(AH_HBCI_GetBankingApi(ob->hbci), 0,
-                                  AB_BANKING_PROGRESS_ONE);
-    if (rv) {
-      DBG_ERROR(AQHBCI_LOGDOMAIN, "User aborted");
-      return rv;
-    }
+  rv=AB_Banking_ExecutionProgress(AH_HBCI_GetBankingApi(ob->hbci), 0);
+  if (rv) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "User aborted");
+    AH_Outbox__FinishOutbox(ob);
+    return rv;
   }
 
   AB_Banking_ProgressLog(AH_HBCI_GetBankingApi(ob->hbci),
@@ -1966,7 +1868,9 @@ int AH_Outbox__Execute(AH_OUTBOX *ob){
 
 
 
-int AH_Outbox_Execute(AH_OUTBOX *ob, int withProgress, int nounmount) {
+int AH_Outbox_Execute(AH_OUTBOX *ob,
+                      AB_IMEXPORTER_CONTEXT *ctx,
+                      int withProgress, int nounmount) {
   int rv;
   GWEN_TYPE_UINT32 pid=0;
 
@@ -1980,6 +1884,7 @@ int AH_Outbox_Execute(AH_OUTBOX *ob, int withProgress, int nounmount) {
 
   }
 
+  ob->context=ctx;
   GWEN_WaitCallback_Enter(AH_OUTBOX_EXECUTE_WCB_ID);
   rv=AH_Outbox__Execute(ob);
   /* unmount currently mounted medium */
@@ -1989,14 +1894,15 @@ int AH_Outbox_Execute(AH_OUTBOX *ob, int withProgress, int nounmount) {
     AB_Banking_ProgressEnd(AH_HBCI_GetBankingApi(ob->hbci), pid);
   }
   GWEN_WaitCallback_Leave();
+  ob->context=0;
   return rv;
 }
 
 
 
 AH_JOB *AH_Outbox__FindTransferJobInCheckJobList(const AH_JOB_LIST *jl,
-                                                 AH_CUSTOMER *cu,
-                                                 AH_ACCOUNT *a,
+                                                 AB_USER *u,
+                                                 AB_ACCOUNT *a,
                                                  int isTransfer) {
   AH_JOB *j;
 
@@ -2029,26 +1935,26 @@ AH_JOB *AH_Outbox__FindTransferJobInCheckJobList(const AH_JOB_LIST *jl,
 
 
 AH_JOB *AH_Outbox_FindTransferJob(AH_OUTBOX *ob,
-                                  AH_CUSTOMER *cu,
-                                  AH_ACCOUNT *a,
+                                  AB_USER *u,
+                                  AB_ACCOUNT *a,
                                   int isTransfer) {
   AH_OUTBOX__CBOX *cbox;
   AH_JOB *j;
 
   assert(ob);
-  assert(cu);
+  assert(u);
   assert(a);
 
   DBG_INFO(AQHBCI_LOGDOMAIN, "Searching for %s job",
             isTransfer?"transfer":"debitnote");
-  cbox=AH_Outbox__CBox_List_First(ob->customerBoxes);
+  cbox=AH_Outbox__CBox_List_First(ob->userBoxes);
   while(cbox) {
-    if (cbox->customer==cu) {
+    if (cbox->user==u) {
       AH_JOBQUEUE *jq;
 
       /* check jobs in lists */
       j=AH_Outbox__FindTransferJobInCheckJobList(cbox->todoJobs,
-                                                 cu, a, isTransfer);
+                                                 u, a, isTransfer);
       if (j)
         return j;
 
@@ -2059,7 +1965,7 @@ AH_JOB *AH_Outbox_FindTransferJob(AH_OUTBOX *ob,
 
         jl=AH_JobQueue_GetJobList(jq);
         if (jl) {
-          j=AH_Outbox__FindTransferJobInCheckJobList(jl, cu, a, isTransfer);
+          j=AH_Outbox__FindTransferJobInCheckJobList(jl, u, a, isTransfer);
           if (j)
             return j;
         }
