@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: job_p.h,v $
                              -------------------
-    cvs         : $Id: job_p.h,v 1.2 2005/08/27 06:29:51 aquamaniac Exp $
+    cvs         : $Id: job_p.h,v 1.4 2006/02/22 19:38:59 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -16,6 +16,7 @@
 
 #include "job_l.h"
 #include <gwenhywfar/stringlist.h>
+#include <gwenhywfar/msgengine.h>
 
 
 
@@ -32,7 +33,7 @@ struct AH_JOB {
 
   char *usedTan;
 
-  AH_CUSTOMER *customer;
+  AB_USER *user;
 
   unsigned int msgNum;
   char *dialogId;
@@ -72,8 +73,8 @@ struct AH_JOB {
 };
 
 
-void AH_Job_SampleResults(AH_JOB *j);
-AH_JOB *AH_Job__freeAll_cb(AH_JOB *j, void *userData);
+static void AH_Job_SampleResults(AH_JOB *j);
+static AH_JOB *AH_Job__freeAll_cb(AH_JOB *j, void *userData);
 
 
 #endif /* AH_JOB_P_H */
