@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: result_p.h,v $
                              -------------------
-    cvs         : $Id: result_p.h,v 1.1 2005/08/05 20:33:12 aquamaniac Exp $
+    cvs         : $Id: result_p.h,v 1.2 2006/02/22 19:38:59 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -13,7 +13,7 @@
 #ifndef AH_RESULT_P_H
 #define AH_RESULT_P_H
 
-#include <aqhbci/result.h>
+#include "result_l.h"
 
 
 struct AH_RESULT {
