@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: dialog_p.h,v $
                              -------------------
-    cvs         : $Id: dialog_p.h,v 1.1 2005/08/05 20:33:12 aquamaniac Exp $
+    cvs         : $Id: dialog_p.h,v 1.4 2006/01/13 13:59:59 cstim Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -14,22 +14,19 @@
 #ifndef GWHBCI_DIALOG_P_H
 #define GWHBCI_DIALOG_P_H
 
-#include <aqhbci/dialog.h>
+#include <gwenhywfar/inetaddr.h>
+#include "dialog_l.h"
 
 
 struct AH_DIALOG {
-  GWEN_LIST_ELEMENT(AH_DIALOG);
-  GWEN_INHERIT_ELEMENT(AH_DIALOG);
-
-  AH_BANK *bank;
   GWEN_TYPE_UINT32 lastMsgNum;
   GWEN_TYPE_UINT32 lastReceivedMsgNum;
   char *dialogId;
-  AH_CUSTOMER *dialogOwner;
+  AB_USER *dialogOwner;
 
   GWEN_MSGENGINE *msgEngine;
 
-  GWEN_NETCONNECTION *connection;
+  GWEN_NETLAYER *netLayer;
 
   GWEN_TYPE_UINT32 flags;
 
@@ -41,13 +38,14 @@ struct AH_DIALOG {
 
 
 
-int AH_Dialog__SendMessageSSL(AH_DIALOG *dlg, AH_MSG *msg);
-int AH_Dialog__SendMessageHBCI(AH_DIALOG *dlg, AH_MSG *msg);
+static int AH_Dialog__SetAddress(AH_DIALOG *dlg,
+                                 GWEN_INETADDRESS *addr,
+                                 const char *bankAddr);
+static int AH_Dialog__CreateNetLayer(AH_DIALOG *dlg);
 
-AH_MSG *AH_Dialog__MsgFromNetMsg_SSL(AH_DIALOG *dlg, GWEN_NETMSG *netmsg);
-AH_MSG *AH_Dialog__MsgFromNetMsg_HBCI(AH_DIALOG *dlg, GWEN_NETMSG *netmsg);
-AH_MSG *AH_Dialog__MsgFromNetMsg(AH_DIALOG *dlg, GWEN_NETMSG *netmsg);
 
+static int AH_Dialog__SendPacket(AH_DIALOG *dlg, const char *buf, int blen,
+                                 int timeout);
 
 
 
