@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: medium.c,v $
                              -------------------
-    cvs         : $Id: medium.c,v 1.6 2005/09/29 03:25:47 aquamaniac Exp $
+    cvs         : $Id: medium.c,v 1.12 2006/03/24 15:27:55 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -76,7 +76,7 @@ void AH_Medium_free(AH_MEDIUM *m){
       free(m->subTypeName);
       free(m->typeName);
       free(m->mediumName);
-      free(m);
+      GWEN_FREE_OBJECT(m);
     }
   }
 }
@@ -146,12 +146,126 @@ void AH_Medium_SubFlags(AH_MEDIUM *m, GWEN_TYPE_UINT32 fl){
 
 
 
+void AH_Medium__preparePatternCtxRdh(GWEN_CRYPTTOKEN_CONTEXT *ctx) {
+  GWEN_CRYPTTOKEN_SIGNINFO *si;
+  GWEN_CRYPTTOKEN_CRYPTINFO *ci;
+  GWEN_CRYPTTOKEN_KEYINFO *ki;
+
+  /* prepare sign info pattern */
+  si=GWEN_CryptToken_SignInfo_new();
+  GWEN_CryptToken_SignInfo_SetHashAlgo(si, GWEN_CryptToken_HashAlgo_RMD160);
+  GWEN_CryptToken_SignInfo_SetPaddAlgo(si,
+                                       GWEN_CryptToken_PaddAlgo_ISO9796_1A4);
+  GWEN_CryptToken_Context_SetSignInfo(ctx, si);
+  GWEN_CryptToken_SignInfo_free(si);
+
+  /* prepare crypt info pattern */
+  ci=GWEN_CryptToken_CryptInfo_new();
+  GWEN_CryptToken_CryptInfo_SetCryptAlgo(ci, GWEN_CryptToken_CryptAlgo_RSA);
+  GWEN_CryptToken_CryptInfo_SetPaddAlgo(ci,
+                                        GWEN_CryptToken_PaddAlgo_LeftZero);
+  GWEN_CryptToken_Context_SetCryptInfo(ctx, ci);
+  GWEN_CryptToken_CryptInfo_free(ci);
+
+  /* prepare key infos */
+  ki=GWEN_CryptToken_KeyInfo_new();
+  GWEN_CryptToken_KeyInfo_SetKeySize(ki, 768);
+  GWEN_CryptToken_KeyInfo_SetChunkSize(ki, 768/8);
+  GWEN_CryptToken_KeyInfo_SetCryptAlgo(ki, GWEN_CryptToken_CryptAlgo_RSA);
+
+  GWEN_CryptToken_Context_SetSignKeyInfo(ctx, ki);
+  GWEN_CryptToken_Context_SetVerifyKeyInfo(ctx, ki);
+  GWEN_CryptToken_Context_SetEncryptKeyInfo(ctx, ki);
+  GWEN_CryptToken_Context_SetDecryptKeyInfo(ctx, ki);
+  GWEN_CryptToken_KeyInfo_free(ki);
+}
+
+
+
+void AH_Medium__preparePatternCtxDdv(GWEN_CRYPTTOKEN_CONTEXT *ctx) {
+  GWEN_CRYPTTOKEN_SIGNINFO *si;
+  GWEN_CRYPTTOKEN_CRYPTINFO *ci;
+  GWEN_CRYPTTOKEN_KEYINFO *ki;
+
+  /* prepare sign info pattern */
+  si=GWEN_CryptToken_SignInfo_new();
+  GWEN_CryptToken_SignInfo_SetHashAlgo(si, GWEN_CryptToken_HashAlgo_RMD160);
+  GWEN_CryptToken_SignInfo_SetPaddAlgo(si, GWEN_CryptToken_PaddAlgo_None);
+  GWEN_CryptToken_Context_SetSignInfo(ctx, si);
+  GWEN_CryptToken_SignInfo_free(si);
+
+  /* prepare crypt info pattern */
+  ci=GWEN_CryptToken_CryptInfo_new();
+  GWEN_CryptToken_CryptInfo_SetCryptAlgo(ci, GWEN_CryptToken_CryptAlgo_DES_3K);
+  GWEN_CryptToken_CryptInfo_SetPaddAlgo(ci, GWEN_CryptToken_PaddAlgo_None);
+  GWEN_CryptToken_Context_SetCryptInfo(ctx, ci);
+  GWEN_CryptToken_CryptInfo_free(ci);
+
+  /* prepare key infos */
+  ki=GWEN_CryptToken_KeyInfo_new();
+  GWEN_CryptToken_KeyInfo_SetKeySize(ki, 16);
+  GWEN_CryptToken_KeyInfo_SetChunkSize(ki, 8);
+  GWEN_CryptToken_KeyInfo_SetCryptAlgo(ki, GWEN_CryptToken_CryptAlgo_DES_3K);
+
+  GWEN_CryptToken_Context_SetSignKeyInfo(ctx, ki);
+  GWEN_CryptToken_Context_SetVerifyKeyInfo(ctx, ki);
+  GWEN_CryptToken_Context_SetEncryptKeyInfo(ctx, ki);
+  GWEN_CryptToken_Context_SetDecryptKeyInfo(ctx, ki);
+  GWEN_CryptToken_KeyInfo_free(ki);
+}
+
+
+
+
+int AH_Medium__findContexts(AH_MEDIUM *m,
+                            GWEN_CRYPTTOKEN *ct,
+                            GWEN_CRYPTTOKEN_CONTEXT_LIST **pList){
+  GWEN_CRYPTTOKEN_CONTEXT_LIST *cl;
+  GWEN_CRYPTTOKEN_CONTEXT *patternCtx;
+  int rv;
+
+  cl=GWEN_CryptToken_Context_List_new();
+  patternCtx=GWEN_CryptToken_Context_new();
+  AH_Medium__preparePatternCtxRdh(patternCtx);
+
+  rv=GWEN_CryptToken_GetMatchingContexts(ct, patternCtx, cl);
+  if (rv==GWEN_ERROR_NO_DATA) {
+    GWEN_CryptToken_Context_free(patternCtx);
+    GWEN_CryptToken_Context_List_free(cl);
+
+    cl=GWEN_CryptToken_Context_List_new();
+    patternCtx=GWEN_CryptToken_Context_new();
+    AH_Medium__preparePatternCtxDdv(patternCtx);
+    rv=GWEN_CryptToken_GetMatchingContexts(ct, patternCtx, cl);
+  }
+
+  if (rv) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "No matching context found (%d)", rv);
+    GWEN_CryptToken_Context_free(patternCtx);
+    GWEN_CryptToken_Context_List_free(cl);
+    return AB_ERROR_NOT_FOUND;
+  }
+  GWEN_CryptToken_Context_free(patternCtx);
+
+  *pList=cl;
+  return 0;
+}
+
+
+
 int AH_Medium__ReadContextsFromToken(AH_MEDIUM *m, GWEN_CRYPTTOKEN *ct){
+  GWEN_CRYPTTOKEN_CONTEXT_LIST *cl;
   GWEN_CRYPTTOKEN_USER_LIST *ul;
   int rv;
 
   assert(m);
 
+  rv=AH_Medium__findContexts(m, ct, &cl);
+  if (rv) {
+    DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
+    return rv;
+  }
+
   /* first try to create by users */
   ul=GWEN_CryptToken_User_List_new();
   rv=GWEN_CryptToken_FillUserList(ct, ul);
@@ -170,70 +284,20 @@ int AH_Medium__ReadContextsFromToken(AH_MEDIUM *m, GWEN_CRYPTTOKEN *ct){
 
       cid=GWEN_CryptToken_User_GetContextId(u);
       if (cid) {
-        const GWEN_CRYPTTOKEN_CONTEXT *tctx;
+        GWEN_CRYPTTOKEN_CONTEXT *tctx;
 
-        tctx=GWEN_CryptToken_GetContextById(ct, cid);
+        tctx=GWEN_CryptToken_FindContextInList(cl, cid);
         if (tctx) {
           AH_MEDIUM_CTX *ctx;
-          GWEN_CRYPTTOKEN_CONTEXT *nctx;
-          const GWEN_CRYPTTOKEN_KEYINFO *ki;
-          const GWEN_CRYPTTOKEN_SIGNINFO *si;
-	  const GWEN_CRYPTTOKEN_CRYPTINFO *ci;
-          GWEN_CRYPTTOKEN_CRYPTALGO algo;
 
-          nctx=GWEN_CryptToken_Context_dup(tctx);
-          assert(nctx);
-
-          ki=GWEN_CryptToken_Context_GetSignKeyInfo(nctx);
-	  assert(ki);
-	  algo=GWEN_CryptToken_KeyInfo_GetCryptAlgo(ki);
-	  if (algo==GWEN_CryptToken_CryptAlgo_RSA) {
-            /* select cryptInfo and signInfo for RDH mode */
-	    si=GWEN_CryptToken_GetSignInfoByAlgos(ct,
-						  GWEN_CryptToken_HashAlgo_RMD160,
-						  GWEN_CryptToken_PaddAlgo_ISO9796_1A4);
-	    ci=GWEN_CryptToken_GetCryptInfoByAlgos(ct,
-						   GWEN_CryptToken_CryptAlgo_RSA,
-						   GWEN_CryptToken_PaddAlgo_LeftZero);
-	  }
-	  else if (algo==GWEN_CryptToken_CryptAlgo_DES_3K) {
-	    /* select cryptInfo and signInfo for DDV mode */
-	    si=GWEN_CryptToken_GetSignInfoByAlgos(ct,
-						  GWEN_CryptToken_HashAlgo_RMD160,
-						  GWEN_CryptToken_PaddAlgo_None);
-	    ci=GWEN_CryptToken_GetCryptInfoByAlgos(ct,
-						   GWEN_CryptToken_CryptAlgo_DES_3K,
-						   GWEN_CryptToken_PaddAlgo_None);
-          }
-          else if (algo==GWEN_CryptToken_CryptAlgo_None) {
-            si=GWEN_CryptToken_GetSignInfoByAlgos(ct,
-                                                  GWEN_CryptToken_HashAlgo_None,
-                                                  GWEN_CryptToken_PaddAlgo_None);
-            ci=GWEN_CryptToken_GetCryptInfoByAlgos(ct,
-                                                   GWEN_CryptToken_CryptAlgo_None,
-                                                   GWEN_CryptToken_PaddAlgo_None);
-          }
-	  else {
-	    DBG_WARN(AQHBCI_LOGDOMAIN,
-		      "Invalid crypt algo \"%s\"",
-		      GWEN_CryptToken_CryptAlgo_toString(algo));
-	    si=0; ci=0;
-	  }
-
-	  if (ci && si) {
-	    GWEN_CryptToken_Context_SetSignInfo(nctx, si);
-	    GWEN_CryptToken_Context_SetCryptInfo(nctx, ci);
-
-	    ctx=AH_MediumCtx_new();
-	    AH_MediumCtx_SetUser(ctx, u);
-	    AH_MediumCtx_SetTokenContext(ctx, nctx);
-	    DBG_INFO(AQHBCI_LOGDOMAIN,
-		      "Adding user \"%s\"",
-		      GWEN_CryptToken_User_GetUserId(u));
-	    AH_MediumCtx_List_Add(ctx, m->contextList);
-	  }
-	  GWEN_CryptToken_Context_free(nctx);
-	}
+          ctx=AH_MediumCtx_new();
+          AH_MediumCtx_SetUser(ctx, u);
+          AH_MediumCtx_SetTokenContext(ctx, tctx);
+          DBG_INFO(AQHBCI_LOGDOMAIN,
+                   "Adding user \"%s\"",
+                   GWEN_CryptToken_User_GetUserId(u));
+          AH_MediumCtx_List_Add(ctx, m->contextList);
+        }
         else {
           DBG_WARN(AQHBCI_LOGDOMAIN, "Context %d not found", (int)cid);
         }
@@ -248,39 +312,29 @@ int AH_Medium__ReadContextsFromToken(AH_MEDIUM *m, GWEN_CRYPTTOKEN *ct){
 
   /* then try to read contexts only */
   if (AH_MediumCtx_List_GetCount(m->contextList)==0) {
-    GWEN_CRYPTTOKEN_CONTEXT_LIST *cl;
+    GWEN_CRYPTTOKEN_CONTEXT *tctx;
+    int idx=1;
 
-    cl=GWEN_CryptToken_Context_List_new();
-    rv=GWEN_CryptToken_FillContextList(ct, cl);
-    if (rv) {
-      DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not fill context list (%d)", rv);
-      GWEN_CryptToken_Context_List_free(cl);
-      return AB_ERROR_NO_DATA;
+    tctx=GWEN_CryptToken_Context_List_First(cl);
+    while (tctx) {
+      AH_MEDIUM_CTX *ctx;
+      GWEN_CRYPTTOKEN_USER *u;
+
+      ctx=AH_MediumCtx_new();
+      AH_MediumCtx_SetTokenContext(ctx, tctx);
+      u=GWEN_CryptToken_User_new();
+      /* create an empty user */
+      GWEN_CryptToken_User_SetId(u, idx);
+      AH_MediumCtx_SetUser(ctx, u);
+      GWEN_CryptToken_User_free(u);
+      AH_MediumCtx_List_Add(ctx, m->contextList);
+      idx++;
+      tctx=GWEN_CryptToken_Context_List_Next(tctx);
     }
-    else {
-      GWEN_CRYPTTOKEN_CONTEXT *tctx;
-      int idx=1;
-
-      tctx=GWEN_CryptToken_Context_List_First(cl);
-      while (tctx) {
-        AH_MEDIUM_CTX *ctx;
-        GWEN_CRYPTTOKEN_USER *u;
-
-	ctx=AH_MediumCtx_new();
-	AH_MediumCtx_SetTokenContext(ctx, tctx);
-	u=GWEN_CryptToken_User_new();
-        /* create an empty user */
-        GWEN_CryptToken_User_SetId(u, idx);
-	AH_MediumCtx_SetUser(ctx, u);
-	GWEN_CryptToken_User_free(u);
-	AH_MediumCtx_List_Add(ctx, m->contextList);
-        idx++;
-	tctx=GWEN_CryptToken_Context_List_Next(tctx);
-      }
-    }
-    GWEN_CryptToken_Context_List_free(cl);
   }
 
+  GWEN_CryptToken_Context_List_free(cl);
+
   /* still no contexts? */
   if (AH_MediumCtx_List_GetCount(m->contextList)==0) {
     DBG_ERROR(AQHBCI_LOGDOMAIN,
@@ -301,6 +355,16 @@ int AH_Medium__MountCt(AH_MEDIUM *m){
 
   assert(m);
 
+  if (m->disableMount) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN,
+              "Refusing to mount medium because there was a pin error");
+    AB_Banking_ProgressLog(AH_HBCI_GetBankingApi(m->hbci),
+                           0, AB_Banking_LogLevelError,
+                           I18N("Refusing to mount medium because "
+                                "there was a pin error"));
+    return AB_ERROR_SECURITY;
+  }
+
   /* get crypt token */
   pm=GWEN_PluginManager_FindPluginManager("crypttoken");
   if (pm==0) {
@@ -331,7 +395,21 @@ int AH_Medium__MountCt(AH_MEDIUM *m){
   if (rv) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not open crypt token (%d)", rv);
     GWEN_CryptToken_free(ct);
-    return AB_ERROR_GENERIC;
+    switch(rv) {
+    case GWEN_ERROR_CT_BAD_PIN:        
+    case GWEN_ERROR_CT_BAD_PIN_0_LEFT:
+    case GWEN_ERROR_CT_BAD_PIN_1_LEFT:
+    case GWEN_ERROR_CT_BAD_PIN_2_LEFT:
+      DBG_ERROR(AQHBCI_LOGDOMAIN,
+                "Disabling mount for this session in order to "
+                "protect the medium");
+      m->disableMount=1;
+      return AB_ERROR_BAD_PIN;
+    case GWEN_ERROR_CT_IO_ERROR:
+      return AB_ERROR_IO;
+    default:
+      return AB_ERROR_GENERIC;
+    }
   }
 
   if (m->flags)
@@ -393,7 +471,7 @@ int AH_Medium_Create(AH_MEDIUM *m){
 
   /* reset */
   assert(m->cryptToken==0);
-  DBG_ERROR(AQHBCI_LOGDOMAIN, "Clearing context list");
+  DBG_INFO(AQHBCI_LOGDOMAIN, "Clearing context list");
   AH_MediumCtx_List_Clear(m->contextList);
   m->currentContext=0;
   m->selected=-1;
@@ -995,6 +1073,9 @@ int AH_Medium_ToDB(const AH_MEDIUM *m, GWEN_DB_NODE *db){
   AH_MEDIUM_CTX *ctx;
   GWEN_DB_NODE *dbX;
 
+  GWEN_DB_SetIntValue(db,
+                      GWEN_DB_FLAGS_DEFAULT | GWEN_DB_FLAGS_OVERWRITE_VARS,
+                      "uniqueId", m->uniqueId);
   GWEN_DB_SetCharValue(db,
                        GWEN_DB_FLAGS_DEFAULT | GWEN_DB_FLAGS_OVERWRITE_VARS,
                        "mediumTypeName", m->typeName);
@@ -1036,6 +1117,9 @@ int AH_Medium_FromDB(AH_MEDIUM *m, GWEN_DB_NODE *db){
   const char *p;
   GWEN_DB_NODE *dbT;
 
+  m->uniqueId=GWEN_DB_GetIntValue(db, "uniqueId", 0, 0);
+  assert(m->uniqueId);
+
   /* mediumName */
   p=GWEN_DB_GetCharValue(db, "mediumName", 0, 0);
   if (p) {
@@ -1432,7 +1516,31 @@ int AH_Medium_CreateKeys(AH_MEDIUM *m){
     DBG_INFO(AQHBCI_LOGDOMAIN, "Error generating local sign key (%d)", rv);
     return rv;
   }
-  GWEN_CryptKey_free(key);
+  else {
+    GWEN_KEYSPEC *ks=0;
+    GWEN_TYPE_UINT32 kid;
+    int rv;
+
+    GWEN_CryptKey_free(key);
+    kid=GWEN_CryptToken_KeyInfo_GetKeyId(kiS);
+    /* get keyspec */
+    rv=GWEN_CryptToken_ReadKeySpec(m->cryptToken, kid, &ks);
+    if (rv) {
+      DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not read key spec (%d)", rv);
+      return rv;
+    }
+    assert(ks);
+    GWEN_KeySpec_SetStatus(ks, GWEN_CRYPTTOKEN_KEYSTATUS_ACTIVE);
+    GWEN_KeySpec_SetKeyName(ks, "S");
+    rv=GWEN_CryptToken_WriteKeySpec(m->cryptToken, kid, ks);
+    if (rv) {
+      DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not write key spec (%d)", rv);
+      GWEN_KeySpec_free(ks);
+      return rv;
+    }
+    AH_MediumCtx_SetLocalSignKeySpec(m->currentContext, ks);
+    GWEN_KeySpec_free(ks);
+  }
 
   /* create local crypt key */
   key=0;
@@ -1441,11 +1549,33 @@ int AH_Medium_CreateKeys(AH_MEDIUM *m){
     DBG_INFO(AQHBCI_LOGDOMAIN, "Error generating local crypt key (%d)", rv);
     return rv;
   }
+  else {
+    GWEN_KEYSPEC *ks=0;
+    GWEN_TYPE_UINT32 kid;
+    int rv;
 
-  GWEN_CryptKey_free(key);
+    GWEN_CryptKey_free(key);
+    kid=GWEN_CryptToken_KeyInfo_GetKeyId(kiC);
+    /* get keyspec */
+    rv=GWEN_CryptToken_ReadKeySpec(m->cryptToken, kid, &ks);
+    if (rv) {
+      DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not read key spec (%d)", rv);
+      return rv;
+    }
+    assert(ks);
+    GWEN_KeySpec_SetStatus(ks, GWEN_CRYPTTOKEN_KEYSTATUS_ACTIVE);
+    GWEN_KeySpec_SetKeyName(ks, "V");
+    rv=GWEN_CryptToken_WriteKeySpec(m->cryptToken, kid, ks);
+    if (rv) {
+      DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not write key spec (%d)", rv);
+      GWEN_KeySpec_free(ks);
+      return rv;
+    }
+    AH_MediumCtx_SetLocalCryptKeySpec(m->currentContext, ks);
+    GWEN_KeySpec_free(ks);
+  }
 
   return 0;
-
 }
 
 
@@ -1473,6 +1603,7 @@ int AH_Medium__ReadKeySpec(AH_MEDIUM *m,
   assert(pks);
 
   /* maybe cache this data later */
+  DBG_INFO(AQHBCI_LOGDOMAIN, "Reading keyspec %x", kid);
   rv=GWEN_CryptToken_ReadKeySpec(m->cryptToken, kid, &ks);
   if (rv) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Unable to read keyspec %x (%d)",
@@ -1527,6 +1658,7 @@ int AH_Medium__ReadKeySpecs(AH_MEDIUM *m) {
   }
   else {
     ks=0;
+    DBG_INFO(AQHBCI_LOGDOMAIN, "Reading keyspec for local sign key");
     rv=AH_Medium__ReadKeySpec(m, GWEN_CryptToken_KeyInfo_GetKeyId(ki), &ks);
     if (rv) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Error reading keyspec (%d)", rv);
@@ -1547,6 +1679,7 @@ int AH_Medium__ReadKeySpecs(AH_MEDIUM *m) {
   }
   else {
     ks=0;
+    DBG_INFO(AQHBCI_LOGDOMAIN, "Reading keyspec for local crypt key");
     rv=AH_Medium__ReadKeySpec(m, GWEN_CryptToken_KeyInfo_GetKeyId(ki), &ks);
     if (rv) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Error reading keyspec (%d)", rv);
@@ -1567,6 +1700,7 @@ int AH_Medium__ReadKeySpecs(AH_MEDIUM *m) {
   }
   else {
     ks=0;
+    DBG_INFO(AQHBCI_LOGDOMAIN, "Reading keyspec for remote sign key");
     rv=AH_Medium__ReadKeySpec(m, GWEN_CryptToken_KeyInfo_GetKeyId(ki), &ks);
     if (rv) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Error reading keyspec (%d)", rv);
@@ -1587,6 +1721,7 @@ int AH_Medium__ReadKeySpecs(AH_MEDIUM *m) {
   }
   else {
     ks=0;
+    DBG_INFO(AQHBCI_LOGDOMAIN, "Reading keyspec for remote crypt key");
     rv=AH_Medium__ReadKeySpec(m, GWEN_CryptToken_KeyInfo_GetKeyId(ki), &ks);
     if (rv) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Error reading keyspec (%d)", rv);
@@ -1657,13 +1792,6 @@ GWEN_CRYPTKEY *AH_Medium_GetLocalPubSignKey(AH_MEDIUM *m){
   }
   assert(key);
 
-  if (GWEN_CryptKey_GetStatus(key)!=GWEN_CRYPTTOKEN_KEYSTATUS_ACTIVE) {
-    DBG_INFO(AQHBCI_LOGDOMAIN, "Key is not active (%d)",
-             GWEN_CryptKey_GetStatus(key));
-    GWEN_CryptKey_free(key);
-    return 0;
-  }
-
   return key;
 }
 
@@ -1699,12 +1827,6 @@ GWEN_CRYPTKEY *AH_Medium_GetLocalPubCryptKey(AH_MEDIUM *m){
     return 0;
   }
   assert(key);
-  if (GWEN_CryptKey_GetStatus(key)!=GWEN_CRYPTTOKEN_KEYSTATUS_ACTIVE) {
-    DBG_INFO(AQHBCI_LOGDOMAIN, "Key is not active (%d)",
-             GWEN_CryptKey_GetStatus(key));
-    GWEN_CryptKey_free(key);
-    return 0;
-  }
 
   return key;
 }
@@ -1920,7 +2042,8 @@ int AH_Medium_ResetServerKeys(AH_MEDIUM *m){
 
 
 
-int AH_Medium__ResetKey(AH_MEDIUM *m, int kid){
+int AH_Medium__SetKeyStatus(AH_MEDIUM *m, int kid,
+                            GWEN_TYPE_UINT32 kstatus){
   GWEN_KEYSPEC *ks=0;
   int rv;
 
@@ -1937,7 +2060,7 @@ int AH_Medium__ResetKey(AH_MEDIUM *m, int kid){
     }
   }
   assert(ks);
-  GWEN_KeySpec_SetStatus(ks, GWEN_CRYPTTOKEN_KEYSTATUS_FREE);
+  GWEN_KeySpec_SetStatus(ks, kstatus);
   rv=GWEN_CryptToken_WriteKeySpec(m->cryptToken, kid, ks);
   if (rv) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not write key spec (%d)", rv);
@@ -1969,7 +2092,8 @@ int AH_Medium_ResetUserKeys(AH_MEDIUM *m){
   /* sign key */
   ki=GWEN_CryptToken_Context_GetSignKeyInfo(tctx);
   if (ki) {
-    rv=AH_Medium__ResetKey(m, GWEN_CryptToken_KeyInfo_GetKeyId(ki));
+    rv=AH_Medium__SetKeyStatus(m, GWEN_CryptToken_KeyInfo_GetKeyId(ki),
+                               GWEN_CRYPTTOKEN_KEYSTATUS_FREE);
     if (rv) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Error resetting sign key (%d)", rv);
       return rv;
@@ -1980,7 +2104,8 @@ int AH_Medium_ResetUserKeys(AH_MEDIUM *m){
   /* crypt key */
   ki=GWEN_CryptToken_Context_GetDecryptKeyInfo(tctx);
   if (ki) {
-    rv=AH_Medium__ResetKey(m, GWEN_CryptToken_KeyInfo_GetKeyId(ki));
+    rv=AH_Medium__SetKeyStatus(m, GWEN_CryptToken_KeyInfo_GetKeyId(ki),
+                               GWEN_CRYPTTOKEN_KEYSTATUS_FREE);
     if (rv) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Error resetting crypt spec (%d)", rv);
       return rv;
@@ -1993,6 +2118,21 @@ int AH_Medium_ResetUserKeys(AH_MEDIUM *m){
 
 
 
+GWEN_TYPE_UINT32 AH_Medium_GetUniqueId(const AH_MEDIUM *m) {
+  return m->uniqueId;
+}
+
+
+
+void AH_Medium_SetUniqueId(AH_MEDIUM *m, GWEN_TYPE_UINT32 id) {
+  m->uniqueId=id;
+}
+
+
+
+
+
+
 
 
 
