@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: mediumheader_p.h,v $
                              -------------------
-    cvs         : $Id: mediumheader_p.h,v 1.1 2005/08/05 20:33:12 aquamaniac Exp $
+    cvs         : $Id: mediumheader_p.h,v 1.2 2006/02/22 19:39:00 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -16,7 +16,7 @@
 
 #define AH_MEDIUMHEADER_MAGIC "#AHM"
 
-#include <aqhbci/mediumheader.h>
+#include "mediumheader_l.h"
 
 
 struct AH_MEDIUMHEADER {
