@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: message.c,v $
                              -------------------
-    cvs         : $Id: message.c,v 1.1 2005/08/05 20:33:12 aquamaniac Exp $
+    cvs         : $Id: message.c,v 1.7 2006/02/22 19:39:00 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -21,8 +21,10 @@
 #include "aqhbci_l.h"
 #include "hbci_l.h"
 #include "mediumctx_l.h"
-
-#include <aqhbci/msgengine.h>
+#include "medium_l.h"
+#include "dialog_l.h"
+#include "msgengine_l.h"
+#include <aqhbci/provider.h>
 
 #include <gwenhywfar/gwenhywfar.h>
 #include <gwenhywfar/debug.h>
@@ -50,8 +52,9 @@ GWEN_LIST_FUNCTIONS(AH_MSG, AH_Msg);
 
 
 
+
 /* --------------------------------------------------------------- FUNCTION */
-GWEN_KEYSPEC *AH_Msg_GetSigners(const AH_MSG *hmsg){
+GWEN_KEYSPEC_LIST *AH_Msg_GetSigners(const AH_MSG *hmsg){
   assert(hmsg);
   return hmsg->signers;
 }
@@ -67,7 +70,7 @@ int AH_Msg_AddSigner(AH_MSG *hmsg, const GWEN_KEYSPEC *ks){
     DBG_ERROR(AQHBCI_LOGDOMAIN, "Signers must be added before nodes !");
     return -1;
   }
-  GWEN_KeySpec_Add(GWEN_KeySpec_dup(ks), &(hmsg->signers));
+  GWEN_KeySpec_List_Add(GWEN_KeySpec_dup(ks), hmsg->signers);
   hmsg->nSigners++;
   return 0;
 }
@@ -173,7 +176,7 @@ AH_MSG *AH_Msg_new(AH_DIALOG *dlg){
   hmsg->buffer=GWEN_Buffer_new(0, AH_MSG_DEFAULTSIZE, 0, 1);
   GWEN_Buffer_ReserveBytes(hmsg->buffer, AH_MSG_DEFAULTRESERVE);
   GWEN_Buffer_SetStep(hmsg->buffer, AH_MSG_DEFAULTSTEP);
-
+  hmsg->signers=GWEN_KeySpec_List_new();
   return hmsg;
 }
 
@@ -184,7 +187,7 @@ void AH_Msg_free(AH_MSG *hmsg){
   if (hmsg) {
     DBG_DEBUG(AQHBCI_LOGDOMAIN, "Destroying AH_MSG");
     GWEN_LIST_FINI(AH_MSG, hmsg);
-    GWEN_KeySpec_Clear(&(hmsg->signers));
+    GWEN_KeySpec_List_free(hmsg->signers);
     GWEN_KeySpec_free(hmsg->crypter);
     GWEN_Buffer_free(hmsg->buffer);
     GWEN_Buffer_free(hmsg->origbuffer);
@@ -200,7 +203,7 @@ void AH_Msg_free(AH_MSG *hmsg){
     }
     GWEN_DB_Group_free(hmsg->decodedMsg);
 
-    free(hmsg);
+    GWEN_FREE_OBJECT(hmsg);
   }
 }
 
@@ -396,9 +399,17 @@ unsigned int AH_Msg_AddNode(AH_MSG *hmsg,
                                           hmsg->buffer,
                                           data);
   if (rv) {
-    DBG_INFO(AQHBCI_LOGDOMAIN, "here");
+    DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
     GWEN_Buffer_Crop(hmsg->buffer, 0, usedBefore);
     GWEN_Buffer_SetPos(hmsg->buffer, usedBefore);
+
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "Buffer:");
+    GWEN_Buffer_Dump(hmsg->buffer, stderr, 2);
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "XML:");
+    GWEN_XMLNode_Dump(node, stderr, 2);
+    DBG_ERROR(0, "MsgEngine - mode: %s version:%d",
+              GWEN_MsgEngine_GetMode(e),
+              GWEN_MsgEngine_GetProtocolVersion(e));
     return 0;
   }
   hmsg->lastSegment=GWEN_MsgEngine_GetIntValue(e,
@@ -475,24 +486,12 @@ unsigned int AH_Msg_InsertNode(AH_MSG *hmsg,
 /* --------------------------------------------------------------- FUNCTION */
 int AH_Msg_EncodeMsg(AH_MSG *hmsg) {
   GWEN_MSGENGINE *e;
-#if 0
-  AH_CUSTOMER *cu;
-  AH_USER *u;
-  AH_BANK *b;
-  AH_MEDIUM *m;
-#endif
+  int rv;
+
   assert(hmsg);
 
   e=AH_Dialog_GetMsgEngine(hmsg->dialog);
   assert(e);
-#if 0
-  cu=AH_Dialog_GetDialogOwner(hmsg->dialog);
-  assert(cu);
-  u=AH_Customer_GetUser(cu);
-  assert(u);
-  b=AH_User_GetBank(u);
-  assert(b);
-#endif
   GWEN_MsgEngine_SetProtocolVersion(e, hmsg->hbciVersion);
 
   if (hmsg->firstSegment==0) {
@@ -521,16 +520,17 @@ int AH_Msg_EncodeMsg(AH_MSG *hmsg) {
     const GWEN_KEYSPEC *ks;
 
     rawBuf=GWEN_Buffer_dup(hmsg->buffer);
-    ks=hmsg->signers;
+    ks=GWEN_KeySpec_List_First(hmsg->signers);
     while (ks) {
       /*DBG_INFO(AQHBCI_LOGDOMAIN, "Signing with this key:");
        GWEN_KeySpec_Dump(ks, stderr, 1);*/
-      if (AH_Msg_SignMsg(hmsg, rawBuf, ks)) {
+      rv=AH_Msg_SignMsg(hmsg, rawBuf, ks);
+      if (rv) {
         GWEN_Buffer_free(rawBuf);
-        DBG_INFO(AQHBCI_LOGDOMAIN, "here");
-        return -1;
+        DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
+        return rv;
       }
-      ks=GWEN_KeySpec_ConstNext(ks);
+      ks=GWEN_KeySpec_List_Next(ks);
     } /* while */
     GWEN_Buffer_free(rawBuf);
   } /* if signing is needed */
@@ -539,23 +539,13 @@ int AH_Msg_EncodeMsg(AH_MSG *hmsg) {
   /* log unencrypted message */
   AH_Msg_LogMessage(hmsg, hmsg->buffer, 0, 0);
 
-#if 0
-  /* get medium */
-  m=AH_HBCI_GetMedium(AH_Medium_GetHBCI(m), cu);
-  if (!m) {
-    DBG_ERROR(AQHBCI_LOGDOMAIN,
-              "Medium for customer \"%s\" is not available",
-              AH_Customer_GetCustomerId(cu));
-    return -1;
-  }
-#endif
-
   /* encrypt message */
   if (hmsg->crypter) {
     DBG_DEBUG(AQHBCI_LOGDOMAIN, "Encrypting message");
-    if (AH_Msg_EncryptMsg(hmsg)) {
-      DBG_INFO(AQHBCI_LOGDOMAIN, "here");
-      return -1;
+    rv=AH_Msg_EncryptMsg(hmsg);
+    if (rv) {
+      DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
+      return rv;
     }
     DBG_DEBUG(AQHBCI_LOGDOMAIN, "Encrypting message: done");
   }
@@ -902,8 +892,7 @@ int AH_Msg_DecodeMsg(AH_MSG *hmsg,
   GWEN_MSGENGINE *e;
   int rv;
   GWEN_DB_NODE *n, *n2;
-  AH_CUSTOMER *cu;
-  AH_USER *u;
+  AB_USER *u;
   AH_MEDIUM *m;
   const char *mode;
   GWEN_TYPE_UINT32 expMsgNum;
@@ -912,9 +901,7 @@ int AH_Msg_DecodeMsg(AH_MSG *hmsg,
   assert(e);
 
   /* set mode */
-  cu=AH_Dialog_GetDialogOwner(hmsg->dialog);
-  assert(cu);
-  u=AH_Customer_GetUser(cu);
+  u=AH_Dialog_GetDialogOwner(hmsg->dialog);
   assert(u);
   m=AH_User_GetMedium(u);
   assert(m);
@@ -1137,10 +1124,10 @@ void AH_Msg__Dump(const AH_MSG *hmsg,
   }
   for (i=0; i<indent; i++) fprintf(f, " ");
   fprintf(f, "Signers (%d):\n", hmsg->nSigners);
-  ks=hmsg->signers;
+  ks=GWEN_KeySpec_List_First(hmsg->signers);
   while(ks) {
     GWEN_KeySpec_Dump(ks, f, indent+2);
-    ks=GWEN_KeySpec_ConstNext(ks);
+    ks=GWEN_KeySpec_List_Next(ks);
   } /* while */
   for (i=0; i<indent; i++) fprintf(f, " ");
   fprintf(f, "Nodes                : %d\n", hmsg->nodes);
@@ -1170,11 +1157,11 @@ AH_DIALOG *AH_Msg_GetDialog(const AH_MSG *hmsg){
 int AH_Msg_IsSignedBy(const AH_MSG *hmsg, const char *s){
   GWEN_KEYSPEC *ks;
 
-  ks=AH_Msg_GetSigners(hmsg);
+  ks=GWEN_KeySpec_List_First(AH_Msg_GetSigners(hmsg));
   while(ks) {
     if (strcasecmp(GWEN_KeySpec_GetOwner(ks), s)==0)
       break;
-    ks=GWEN_KeySpec_Next(ks);
+    ks=GWEN_KeySpec_List_Next(ks);
   } /* while */
   if (ks) {
     DBG_DEBUG(AQHBCI_LOGDOMAIN, "Message signed by \"%s\"", s);
@@ -1303,37 +1290,6 @@ void AH_Msg_SetHbciVersion(AH_MSG *hmsg, unsigned int i) {
 
 
 
-/* --------------------------------------------------------------- FUNCTION */
-void AH_Msg_SetDecodedMsg(AH_MSG *msg, GWEN_DB_NODE *db){
-  assert(msg);
-  assert(db);
-
-  GWEN_DB_Group_free(msg->decodedMsg);
-  msg->decodedMsg=db;
-}
-
-
-
-/* --------------------------------------------------------------- FUNCTION */
-GWEN_DB_NODE *AH_Msg_GetDecodedMsg(const AH_MSG *msg){
-  assert(msg);
-  return msg->decodedMsg;
-}
-
-
-
-/* --------------------------------------------------------------- FUNCTION */
-GWEN_DB_NODE *AH_Msg_TakeDecodedMsg(AH_MSG *msg){
-  GWEN_DB_NODE *db;
-
-  assert(msg);
-  db=msg->decodedMsg;
-  msg->decodedMsg=0;
-  return db;
-}
-
-
-
 /* --------------------------------------------------------------- FUNCTION */
 void AH_Msg_SetTan(AH_MSG *hmsg, const char *s){
   assert(hmsg);
@@ -1390,10 +1346,8 @@ void AH_Msg_LogMessage(AH_MSG *msg,
                        int rec,
                        int crypt) {
   GWEN_DB_NODE *db;
-  AH_CUSTOMER *cu;
-  AH_USER *u;
+  AB_USER *u;
   AH_MEDIUM *m;
-  AH_BANK *b;
   AH_HBCI *h;
   GWEN_BUFFEREDIO *bio;
   int fd;
@@ -1414,9 +1368,7 @@ void AH_Msg_LogMessage(AH_MSG *msg,
   }
 
   db=GWEN_DB_Group_new("header");
-  cu=AH_Dialog_GetDialogOwner(msg->dialog);
-  u=AH_Customer_GetUser(cu);
-  b=AH_User_GetBank(u);
+  u=AH_Dialog_GetDialogOwner(msg->dialog);
   m=AH_User_GetMedium(u);
   assert(m);
   h=AH_Medium_GetHBCI(m);
@@ -1658,6 +1610,7 @@ const char *AH_Msg_GetPin(const AH_MSG *msg){
 
 
 
+#include "msgcrypt.inc"
 
 
 
