@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: user_p.h,v $
                              -------------------
-    cvs         : $Id: user_p.h,v 1.1 2005/08/05 20:33:13 aquamaniac Exp $
+    cvs         : $Id: user_p.h,v 1.3 2006/02/22 19:39:00 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -14,36 +14,23 @@
 #define AH_USER_P_H
 
 #include "user_l.h"
-#include "customer_l.h"
-#include "bpd.h"
 
 
+typedef struct AH_USER AH_USER;
 struct AH_USER {
-  GWEN_LIST_ELEMENT(AH_USER);
-
-  AH_BANK *bank;
-  char *userId;
+  AH_HBCI *hbci;
+  GWEN_MSGENGINE *msgEngine;
 
   AH_MEDIUM *medium;
-  int contextIdx;
-
-  GWEN_TYPE_UINT32 usage;
-
-  AH_CUSTOMER_LIST *customers;
-
-  /* adjustable vars */
-  AH_USER_STATUS status;
-  /* only from here the server addres is taken !! */
-  AH_BPD_ADDR *serverAddress;
-
-  AH_CRYPT_MODE cryptMode;
-
-  /* new variables used with CryptTokens */
-  char *peerId;
 
+  GWEN_URL *serverUrl;
+  AH_BPD *bpd;
 
+  GWEN_TYPE_UINT32 flags;
 };
 
+static void AH_User_freeData(void *bp, void *p);
+
 
 
 #endif /* AH_USER_P_H */
