@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: iniletter.c,v $
  -------------------
- cvs         : $Id: iniletter.c,v 1.3 2005/08/30 08:33:47 aquamaniac Exp $
+ cvs         : $Id: iniletter.c,v 1.7 2006/03/17 10:35:21 cstim Exp $
  begin       : Tue May 03 2005
  copyright   : (C) 2005 by Martin Preuss
  email       : martin@libchipcard.de
@@ -16,9 +16,7 @@
 
 
 #include "globals.h"
-
-#include <aqhbci/outbox.h>
-#include <aqhbci/adminjobs.h>
+#include <aqhbci/user.h>
 
 #include <gwenhywfar/text.h>
 #include <gwenhywfar/md.h>
@@ -36,9 +34,8 @@ int iniLetter(AB_BANKING *ab,
               char **argv) {
   GWEN_DB_NODE *db;
   AB_PROVIDER *pro;
-  AH_HBCI *hbci;
-  AH_CUSTOMER_LIST2 *cl;
-  AH_CUSTOMER *cu=0;
+  AB_USER_LIST2 *ul;
+  AB_USER *u=0;
   int rv;
   const char *bankId;
   const char *userId;
@@ -64,8 +61,8 @@ int iniLetter(AB_BANKING *ab,
     1,                            /* maxnum */
     "c",                          /* short option */
     "customer",                   /* long option */
-    "Specify the customer id",    /* short description */
-    "Specify the customer id"     /* long description */
+    "Specify the customer id (Kundennummer)",    /* short description */
+    "Specify the customer id (Kundennummer)"     /* long description */
   },
   {
     0, /* flags */
@@ -121,40 +118,37 @@ int iniLetter(AB_BANKING *ab,
 
   pro=AB_Banking_GetProvider(ab, "aqhbci");
   assert(pro);
-  hbci=AH_Provider_GetHbci(pro);
-  assert(hbci);
 
   bankId=GWEN_DB_GetCharValue(db, "bankId", 0, "*");
   userId=GWEN_DB_GetCharValue(db, "userId", 0, "*");
   customerId=GWEN_DB_GetCharValue(db, "customerId", 0, "*");
   bankKey=GWEN_DB_VariableExists(db, "bankKey");
 
-  cl=AH_HBCI_GetCustomers(hbci, 280, bankId, userId, customerId);
-  if (cl) {
-    if (AH_Customer_List2_GetSize(cl)!=1) {
+  ul=AB_Banking_FindUsers(ab, AH_PROVIDER_NAME,
+                          "de", bankId, userId, customerId);
+  if (ul) {
+    if (AB_User_List2_GetSize(ul)!=1) {
       DBG_ERROR(0, "Ambiguous customer specification");
       AB_Banking_Fini(ab);
       return 3;
     }
     else {
-      AH_CUSTOMER_LIST2_ITERATOR *cit;
+      AB_USER_LIST2_ITERATOR *cit;
 
-      cit=AH_Customer_List2_First(cl);
+      cit=AB_User_List2_First(ul);
       assert(cit);
-      cu=AH_Customer_List2Iterator_Data(cit);
-      AH_Customer_List2Iterator_free(cit);
+      u=AB_User_List2Iterator_Data(cit);
+      AB_User_List2Iterator_free(cit);
     }
-    AH_Customer_List2_free(cl);
+    AB_User_List2_free(ul);
   }
-  if (!cu) {
+  if (!u) {
     DBG_ERROR(0, "No matching customer");
     AB_Banking_Fini(ab);
     return 3;
   }
   else {
-    AH_USER *u;
     AH_MEDIUM *m;
-    AH_BANK *b;
     GWEN_CRYPTKEY *key;
     GWEN_DB_NODE *dbKey;
     const void *p;
@@ -167,12 +161,8 @@ int iniLetter(AB_BANKING *ab,
     char numbuf[32];
     char hashbuffer[21];
 
-    u=AH_Customer_GetUser(cu);
-    assert(u);
     m=AH_User_GetMedium(u);
     assert(m);
-    b=AH_User_GetBank(u);
-    assert(b);
 
     rv=AH_Medium_Mount(m);
     if (rv) {
@@ -216,7 +206,7 @@ int iniLetter(AB_BANKING *ab,
     }
 
     dbKey=GWEN_DB_Group_new("keydata");
-    if (GWEN_CryptKey_ToDb(key, dbKey, 1)) {
+    if (GWEN_CryptKey_toDb(key, dbKey, 1)) {
       GWEN_DB_Group_free(dbKey);
       DBG_ERROR(0, "Bad key.");
       AB_Banking_Fini(ab);
@@ -243,12 +233,12 @@ int iniLetter(AB_BANKING *ab,
     if (bankKey) {
       GWEN_Buffer_AppendString(lbuf,
                                I18N("Bank           : "));
-      GWEN_Buffer_AppendString(lbuf, AH_Bank_GetBankId(b));
+      GWEN_Buffer_AppendString(lbuf, AB_User_GetBankCode(u));
     }
     else {
       GWEN_Buffer_AppendString(lbuf,
                                I18N("User           : "));
-      GWEN_Buffer_AppendString(lbuf, AH_User_GetUserId(u));
+      GWEN_Buffer_AppendString(lbuf, AB_User_GetUserId(u));
     }
 
     GWEN_Buffer_AppendString(lbuf, "\n");
@@ -269,7 +259,7 @@ int iniLetter(AB_BANKING *ab,
     if (!bankKey) {
       GWEN_Buffer_AppendString(lbuf,
                                I18N("Customer system: "));
-      GWEN_Buffer_AppendString(lbuf, AH_HBCI_GetProductName(hbci));
+      GWEN_Buffer_AppendString(lbuf, AH_Provider_GetProductName(pro));
       GWEN_Buffer_AppendString(lbuf, "\n");
     }
 
